/*
*  program name: Rubrica -- http://digilander.iol.it/nfragale/download.html
*  file: prefer_int.c
*  
*  build the graphic interface for preferences dialog
*
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <config.h>

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <gnome.h>
#include <gconf/gconf-client.h>
#include <gconf/gconf-value.h>
#include <gconf/gconf-schema.h>

#include "prefer.h"
#include "prefer_cb.h"
#include "prefer_int.h"
#include "prefer_configure.h"
#include "rubrica_ui.h"
#include "rubrica_type.h"
#include "dialog.h"
#include "utils.h"
#include "error.h"


static GtkWidget*   preferences_dialog = NULL;
static GtkWidget*   notebook = NULL;
static GtkTooltips* tooltips;



RubricaPreferItem file[] =  {
  {N_("Defaults"),      "folder.png",   TRUE, rubrica_preferences_default, NULL},
  {N_("File Settings"), "filesett.png", TRUE, rubrica_preferences_file_settings, NULL},
  {NULL}    
};

RubricaPreferItem general[] =  {
  {N_("Search and Order"), "search.png",  TRUE, rubrica_preferences_search, NULL},
  {N_("Misc"),             "misc.png",    TRUE, rubrica_preferences_misc, NULL},
  {NULL}
};

RubricaPreferItem view[] =  {
  {
    N_("Card columns view"), "view-column.png", TRUE, 
    rubrica_preferences_view_cards_columns, NULL
  },
  {
    N_("Personal Data view"), "personal.png", TRUE, 
    rubrica_preferences_view_personal_data, NULL
  },
  {N_("Company Data view"), "company.png", TRUE, rubrica_preferences_view_company_data, NULL},
  {N_("Notes view"), "notes.png", TRUE, rubrica_preferences_view_note_data, NULL},
  {N_("Accounts view"), "accounts.png", TRUE, rubrica_preferences_view_account_columns, NULL},
  {NULL}
};

RubricaPreferItem crypto[] =  {
  {N_("Cryptography"),   "crypto.png",  TRUE, rubrica_not_implemented, NULL},
  {NULL}
};

RubricaPreferItem translation[] =  {
  {N_("Rubrica Dictionary"),   "dictionary.png",  TRUE, rubrica_preferences_dictionary, NULL},
  {NULL}
};


RubricaPreferItem rpi[] =  {
  /* label, pixmap file, notebook page flag, notebook page's function builder, children */
  {N_("File"),         "file.png",        TRUE, rubrica_preferences_file_info,    file},
  {N_("General"),      "general.png",     TRUE, rubrica_preferences_general_info, general},
  {N_("View"),         "view.png",        TRUE, rubrica_preferences_view_info,    view},
  {N_("Cryptography"), "crypto.png",      TRUE, rubrica_preferences_crypto_info,  crypto},
  {N_("Translation"),  "translation.png", TRUE, rubrica_preferences_trans_info,   translation},
  {NULL}
};

   
RubricaPreferItem card_columns[] = {
  /* label, key, default value, not used, not used */  
  {N_("Show categories pixmap column"), RUBRICA_KEY_SHOW_CARD_COLUMN_PIXMAP, TRUE, NULL, NULL},
  {N_("Show card column"),       RUBRICA_KEY_SHOW_CARD_COLUMN_CARD,       TRUE,  NULL, NULL},
  {N_("Show first name column"), RUBRICA_KEY_SHOW_CARD_COLUMN_FIRST_NAME, TRUE,  NULL, NULL},
  {N_("Show last name column"),  RUBRICA_KEY_SHOW_CARD_COLUMN_LAST_NAME,  TRUE,  NULL, NULL},
  {N_("Show profession column"), RUBRICA_KEY_SHOW_CARD_COLUMN_PROFESSION, FALSE, NULL, NULL},
  {N_("Show city column"),       RUBRICA_KEY_SHOW_CARD_COLUMN_CITY,       FALSE, NULL, NULL},
  {N_("Show country column"),    RUBRICA_KEY_SHOW_CARD_COLUMN_COUNTRY,    FALSE, NULL, NULL},
  {N_("Show web column"),        RUBRICA_KEY_SHOW_CARD_COLUMN_WEB,        TRUE,  NULL, NULL},
  {N_("Show email column"),      RUBRICA_KEY_SHOW_CARD_COLUMN_EMAIL,      TRUE,  NULL, NULL},
  {N_("Show telephone column"),  RUBRICA_KEY_SHOW_CARD_COLUMN_TELEPHONE,  FALSE, NULL, NULL},
  {N_("Show company column"),    RUBRICA_KEY_SHOW_CARD_COLUMN_COMPANY,    FALSE, NULL, NULL},
  {N_("Show assigment column"),  RUBRICA_KEY_SHOW_CARD_COLUMN_ASSIGMENT,  FALSE, NULL, NULL},
  {N_("Show categories column"), RUBRICA_KEY_SHOW_CARD_COLUMN_CATEGORIES, FALSE, NULL, NULL},
  {NULL}
};

RubricaPreferItem account_columns[] = {
  /* label, key, default value, not used, not used */  
  {N_("Show site column"),        RUBRICA_KEY_SHOW_ACCOUNT_COLUMN_SITE,  TRUE,  NULL, NULL},
  {N_("Show web url column"),     RUBRICA_KEY_SHOW_ACCOUNT_COLUMN_WEB,   TRUE,  NULL, NULL},
  {N_("Show email column"),       RUBRICA_KEY_SHOW_ACCOUNT_COLUMN_EMAIL, FALSE, NULL, NULL},
  {N_("Show login column"),       RUBRICA_KEY_SHOW_ACCOUNT_COLUMN_LOGIN, TRUE,  NULL, NULL},
  {N_("Show password column"),    RUBRICA_KEY_SHOW_ACCOUNT_COLUMN_PWORD, TRUE,  NULL, NULL},
  {N_("Show description column"), RUBRICA_KEY_SHOW_ACCOUNT_COLUMN_DESC,  FALSE, NULL, NULL},
  {NULL}
};

RubricaPreferItem personal_data[] = {
  {N_("Show first name"),    RUBRICA_KEY_SHOW_DATA_FIRST_NAME,  TRUE,  NULL, NULL},
  {N_("Show middle name"),   RUBRICA_KEY_SHOW_DATA_MIDDLE_NAME, FALSE, NULL, NULL},
  {N_("Show last name"),     RUBRICA_KEY_SHOW_DATA_LAST_NAME,   TRUE,  NULL, NULL},
  {N_("Show profession"),    RUBRICA_KEY_SHOW_DATA_PROFESSION,  TRUE,  NULL, NULL},
  {N_("Show name prefix"),   RUBRICA_KEY_SHOW_DATA_NAME_PREFIX, FALSE, NULL, NULL},
  {N_("Show title"),         RUBRICA_KEY_SHOW_DATA_TITLE,       FALSE, NULL, NULL},
  {N_("Show birthday"),      RUBRICA_KEY_SHOW_DATA_BIRTHDAY,    TRUE,  NULL, NULL},
  {N_("Show street"),        RUBRICA_KEY_SHOW_DATA_STREET,      TRUE,  NULL, NULL},
  {N_("Show street number"), RUBRICA_KEY_SHOW_DATA_STREET_NUM,  FALSE, NULL, NULL},
  {N_("Show zip code"),      RUBRICA_KEY_SHOW_DATA_ZIP_CODE,    FALSE, NULL, NULL},
  {N_("Show city"),          RUBRICA_KEY_SHOW_DATA_CITY,        TRUE,  NULL, NULL},
  {N_("Show province"),      RUBRICA_KEY_SHOW_DATA_PROVINCE,    TRUE,  NULL, NULL},
  {N_("Show state"),         RUBRICA_KEY_SHOW_DATA_STATE,       FALSE, NULL, NULL},
  {N_("Show country"),       RUBRICA_KEY_SHOW_DATA_COUNTRY,     TRUE,  NULL, NULL},
  {N_("Show web urls"),      RUBRICA_KEY_SHOW_DATA_WEB,         TRUE,  NULL, NULL},
  {N_("Show emails"),        RUBRICA_KEY_SHOW_DATA_EMAIL,       TRUE,  NULL, NULL},
  {N_("Show telephone numbers"), RUBRICA_KEY_SHOW_DATA_TELEPHONE, TRUE, NULL, NULL},
  {NULL}
};

RubricaPreferItem company_data[] = {
  {N_("Show company name"),   RUBRICA_KEY_SHOW_DATA_COMPANY,        TRUE,  NULL, NULL},
  {N_("Show company street"), RUBRICA_KEY_SHOW_DATA_JOB_STREET,     TRUE,  NULL, NULL},
  {N_("Show street number"),  RUBRICA_KEY_SHOW_DATA_JOB_STREET_NUM, FALSE, NULL, NULL},
  {N_("Show zip code"),       RUBRICA_KEY_SHOW_DATA_JOB_ZIP_CODE,   FALSE, NULL, NULL},
  {N_("Show city"),           RUBRICA_KEY_SHOW_DATA_JOB_CITY,       TRUE,  NULL, NULL},
  {N_("Show province"),       RUBRICA_KEY_SHOW_DATA_JOB_PROVINCE,   TRUE,  NULL, NULL},
  {N_("Show country"),        RUBRICA_KEY_SHOW_DATA_JOB_COUNTRY,    TRUE,  NULL, NULL},
  {N_("Show web url"),        RUBRICA_KEY_SHOW_DATA_JOB_WEB,        TRUE,  NULL, NULL},
  {N_("Show email"),          RUBRICA_KEY_SHOW_DATA_JOB_EMAIL,      TRUE,  NULL, NULL},
  {N_("Show operator"),       RUBRICA_KEY_SHOW_DATA_OPERATOR,       TRUE,  NULL, NULL},
  {N_("Show fax"),            RUBRICA_KEY_SHOW_DATA_FAX,            TRUE,  NULL, NULL},
  {N_("Show green"),          RUBRICA_KEY_SHOW_DATA_GREEN,          TRUE,  NULL, NULL},
  {N_("Show customer care"),  RUBRICA_KEY_SHOW_DATA_CUSTOMER_CARE,  TRUE,  NULL, NULL},
  {N_("Show company notes"),  RUBRICA_KEY_SHOW_DATA_JOB_NOTE,       FALSE, NULL, NULL},
  {N_("Show contact assigment"), RUBRICA_KEY_SHOW_DATA_ASSIGMENT,   TRUE,  NULL, NULL},
  {N_("Show organizzation"),  RUBRICA_KEY_SHOW_DATA_ORG,            FALSE, NULL, NULL},
  {N_("Show department"),     RUBRICA_KEY_SHOW_DATA_DEP,            FALSE, NULL, NULL},
  {N_("Show sub department"), RUBRICA_KEY_SHOW_DATA_SUB_DEP,        FALSE, NULL, NULL},
  {N_("Show secretary (company contact)"), RUBRICA_KEY_SHOW_DATA_SECRETARY, FALSE, NULL, NULL},
  {N_("Show secretary telephone"), RUBRICA_KEY_SHOW_DATA_SECR_PHONE, FALSE, NULL, NULL},
  {NULL}
};

RubricaPreferItem note_data[] = {
  {N_("Show TODO: tradurre stato civile"), RUBRICA_KEY_SHOW_DATA_MARRIED,  TRUE,  NULL, NULL},
  {N_("Show spouse's name"),        RUBRICA_KEY_SHOW_DATA_SPOUSE,          TRUE,  NULL, NULL},
  {N_("Show spouse's birthday"),    RUBRICA_KEY_SHOW_DATA_SPOUSE_BIRTH,    TRUE,  NULL, NULL},
  {N_("Show marriage anniversary"), RUBRICA_KEY_SHOW_DATA_ANNIVERSARY,     TRUE,  NULL, NULL},
  {N_("Show if contact has children"), RUBRICA_KEY_SHOW_DATA_HAS_CHILDREN, FALSE, NULL, NULL},
  {N_("Show children's notes"),     RUBRICA_KEY_SHOW_DATA_CHILDREN,        FALSE, NULL, NULL},
  {N_("Show contact's hobbies"),    RUBRICA_KEY_SHOW_DATA_HOBBIES,         TRUE,  NULL, NULL},
  {N_("Show notes"),                RUBRICA_KEY_SHOW_DATA_NOTE,            TRUE,  NULL, NULL},
  {N_("Show contact's public key"), RUBRICA_KEY_SHOW_DATA_PUBLIC_KEY,      TRUE,  NULL, NULL},
 {NULL}
};


GtkWidget* rubrica_preferences_get_preferencesbox(void)
{
  return (GtkWidget*) preferences_dialog;
}


GtkWidget* rubrica_preferences_get_notebook(void)
{
  return (GtkWidget*) notebook;
}


/* create the model for preferences index tree 
*/
GtkTreeModel*
rubrica_preferences_create_tree_model(GConfClient *client)
{
  GtkTreeStore *model;
  GtkTreeIter iter;
  RubricaPreferItem *mainitem = rpi;

  model = gtk_tree_store_new(RP_LAST_COLUMN, 
			     GDK_TYPE_PIXBUF,  /* pixmap      */
			     G_TYPE_STRING,    /* string      */ 
			     G_TYPE_BOOLEAN,   /* have_page   */
			     G_TYPE_INT);      /* page number */

  while(mainitem->label)
    {
      RubricaPreferItem *child = mainitem->children;
      GdkPixbuf *image;
      gint page;

      if (mainitem->func)
	page = mainitem->func(client, mainitem->label);
      else 
	page = -2;  /* -1 is used in gtk_tree_store_set to identify list's end */
      
      image = rubrica_ui_pixbuf_new(mainitem->str);

      gtk_tree_store_append(model, &iter, NULL);
      gtk_tree_store_set(model, &iter, 
			 RP_PIXMAP_COLUMN, image, 
			 RP_STRING_COLUMN, mainitem->label, 
			 RP_HAVE_PAGE,     mainitem->bool,
			 RP_PAGE_COLUMN,   page, 
			 -1);
			 
      while (child->label)
	{
	  GtkTreeIter child_iter;

	  if (child->func)
	    page = child->func(client, child->label);
	  else 
	    page = -2;  /* -1 is used in gtk_tree_store_set to identify list's end */
	  
	  image = rubrica_ui_pixbuf_new(child->str);
	  
	  gtk_tree_store_append(model, &child_iter, &iter);
	  gtk_tree_store_set(model, &child_iter, 
			     RP_PIXMAP_COLUMN, image, 
			     RP_STRING_COLUMN, child->label, 
			     RP_HAVE_PAGE,     child->bool,
			     RP_PAGE_COLUMN,   page, 
			     -1);	  

	  child++;
	}

      mainitem++;
    }

  return GTK_TREE_MODEL(model);
}


/* create the view for preferences tree 
*/
GtkWidget*
rubrica_preferences_create_new_tree_view(GtkTreeModel *model, GtkWidget *notebook)
{
  GtkWidget *treeview;
  GtkTreeSelection *selection;

  treeview  = gtk_tree_view_new_with_model(model);
  selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
  gtk_widget_show(treeview);

  g_object_unref(G_OBJECT(model));

  gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(treeview), FALSE);
  gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(treeview), FALSE);
  gtk_tree_view_columns_autosize(GTK_TREE_VIEW(treeview));
  gtk_tree_selection_set_mode(selection, GTK_SELECTION_SINGLE);

  rubrica_preferences_add_columns(GTK_TREE_VIEW(treeview), PREF_TREE);
  gtk_tree_view_expand_all(GTK_TREE_VIEW(treeview));

  g_signal_connect(G_OBJECT(selection), "changed", 
		   G_CALLBACK(rubrica_preferences_row_selected), treeview);
  
  return treeview;
}


/* create a list model for card's column manage
 */
GtkTreeModel*
rubrica_preferences_create_list_model(GConfClient *client, RubricaTreeType type)
{
  GtkListStore *model;
  GtkTreeIter iter;  
  RubricaPreferItem *listitem = NULL; 

  model = gtk_list_store_new(RP_VIEW_LAST_COLUMN,
			     G_TYPE_BOOLEAN,
			     G_TYPE_STRING, 
			     G_TYPE_STRING);

  switch (type)
    {
    case PREF_CARD_LIST:
      listitem = card_columns;
      break;

    case PREF_ACCOUNT_LIST:
      listitem = account_columns;
      break;

    case PREF_PERSONAL_DATA_LIST:
      listitem = personal_data;
      break;

    case PREF_COMPANY_DATA_LIST:
      listitem = company_data;     
	break;

    case PREF_NOTE_DATA_LIST:
      listitem = note_data;
      break;

    default:
      g_warning("can't create model in rubrica_preferences_create_list_model(). Type is: %d",
		(RubricaTreeType) type);

      return NULL;;
      break;
    }

  while (listitem->label)
    {
      GConfValue  *value;
      gchar *key;
      gboolean bool;
      
      key = listitem->str;
      value = gconf_client_get(client, key, NULL);
      if (value == NULL || value->type != GCONF_VALUE_BOOL)
	{
	  bool = listitem->bool;
	}
      else 
	bool = gconf_client_get_bool(client, key, NULL); 
      
      gtk_list_store_append(GTK_LIST_STORE(model), &iter);
      gtk_list_store_set(GTK_LIST_STORE(model), &iter, 
			 RP_VIEW_CHECK_COLUMN, bool,
			 RP_VIEW_LABEL_COLUMN, listitem->label, 
			 RP_VIEW_KEY_COLUMN,   key,
			 -1);
      listitem++;
    }
    
  return GTK_TREE_MODEL(model);    
}


/* create a list view using a card or account or data model 
*/
GtkWidget*
rubrica_preferences_create_list_view_with_model(GtkTreeModel *model, RubricaTreeType type)
{
  GtkWidget *listview;
  GtkTreeSelection *selection;

  listview  = gtk_tree_view_new_with_model(model);
  selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(listview));
  gtk_widget_show(listview);

  gtk_tree_selection_set_mode(selection, GTK_SELECTION_SINGLE);

  if (type == PREF_TREE)
    {
      gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(listview), FALSE);
      gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(listview), FALSE);
    }
  else
    {
      gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(listview), TRUE);
      gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(listview), TRUE);
    }

  rubrica_preferences_add_columns(GTK_TREE_VIEW(listview), type);
  gtk_tree_view_expand_all(GTK_TREE_VIEW(listview));

  return listview;
}


/* add the rigth columns to the list view 
*/
void 
rubrica_preferences_add_columns(GtkTreeView *tree, RubricaTreeType type)
{
  GtkCellRenderer *cell;
  GtkTreeModel *model;
  GtkTreeViewColumn *column;
  gint col;

  model = gtk_tree_view_get_model(tree);

  if (type == PREF_TREE)
    {
      cell = gtk_cell_renderer_pixbuf_new();
      gtk_tree_view_insert_column_with_attributes(tree, -1, NULL, cell, "pixbuf",
						  RP_PIXMAP_COLUMN, NULL);
      
      cell = gtk_cell_renderer_text_new();
      gtk_tree_view_insert_column_with_attributes(tree, -1, NULL, cell, "text", 
						  RP_STRING_COLUMN, NULL); 
    }
  else
    {
      cell = gtk_cell_renderer_toggle_new();
      col  = gtk_tree_view_insert_column_with_attributes(tree, -1, _("Status"), 
							 cell, "active", 
							 RP_VIEW_CHECK_COLUMN, NULL); 
      column = gtk_tree_view_get_column(tree, col-1);
      gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN(column),GTK_TREE_VIEW_COLUMN_FIXED);
      gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN(column), 50);
      gtk_tree_view_column_set_max_width (GTK_TREE_VIEW_COLUMN(column), 50);
     
      g_signal_connect(G_OBJECT(cell), "toggled", 
		       G_CALLBACK(rubrica_preferences_manage_columns), model);
      
      cell = gtk_cell_renderer_text_new();
      gtk_tree_view_insert_column_with_attributes(tree, -1, _("Column description"), 
						  cell, "text", RP_VIEW_LABEL_COLUMN, NULL); 
    }
}


/*    list/tree view callbacks 
*/
void 
rubrica_preferences_manage_columns(GtkCellRendererToggle *cell, 
				   gchar *path_str, gpointer data)
{
  GtkTreeModel *model;
  GtkTreeIter iter;
  GtkTreePath *path;
  GConfClient *client;
  gboolean status;      /* check status */
  gchar *key;

  model  = (GtkTreeModel *) data;
  path   = gtk_tree_path_new_from_string(path_str);
  client = gconf_client_get_default ();

  gtk_tree_model_get_iter (model, &iter, path);
  gtk_tree_model_get (model, &iter,
		      RP_VIEW_CHECK_COLUMN, &status, 
		      RP_VIEW_KEY_COLUMN,   &key, 
		      -1);
  status ^= 1;
  gtk_list_store_set(GTK_LIST_STORE(model), &iter, RP_VIEW_CHECK_COLUMN, status, -1);
  gconf_client_set_bool (client, key, status, NULL);
}


/*    list/tree view callbacks 
*/
void 
rubrica_preferences_row_selected(GtkTreeSelection *select, gpointer data)
{
  GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(data));
  GtkTreeIter iter;
  gint page;
  gboolean have_page;
  
  if (gtk_tree_selection_get_selected(select, &model, &iter))
    {
      gtk_tree_model_get(model, &iter, 
			 RP_HAVE_PAGE,   &have_page, 
			 RP_PAGE_COLUMN, &page, 
			 -1);

      if (have_page)
	gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), page);      
    }  
}


/*    preferences interface creation
*/
GtkWidget*
create_preferences_dialog (GtkWidget *app, GConfClient *client)
{
  GtkWidget *tree;
  GtkTreeModel *model;

  GtkWidget *dialog_vbox;
  GtkWidget *hbox;

  preferences_dialog = gtk_dialog_new_with_buttons(_("Rubrica Preferences"), 
						   GTK_WINDOW(app), 
						   GTK_DIALOG_MODAL,
						   GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
						   NULL);
  notebook = gtk_notebook_new ();
  tooltips = gtk_tooltips_new ();
  model    = rubrica_preferences_create_tree_model(client);
  tree     = rubrica_preferences_create_new_tree_view(model, notebook);  

  rubrica_utils_add_tooltip(tooltips);

  gtk_notebook_set_show_tabs(GTK_NOTEBOOK(notebook), FALSE);
  rubrica_preferences_reset_errors();
  
  gtk_dialog_set_has_separator (GTK_DIALOG(preferences_dialog), TRUE);
  gtk_window_set_position (GTK_WINDOW (preferences_dialog), GTK_WIN_POS_CENTER);
  gtk_window_set_policy (GTK_WINDOW (preferences_dialog), FALSE, FALSE, FALSE);

  dialog_vbox = GTK_DIALOG (preferences_dialog)->vbox;
  gtk_container_set_border_width (GTK_CONTAINER (dialog_vbox), 2);
  gtk_widget_show (dialog_vbox);

  hbox = rubrica_ui_box_new(HBOX, FALSE, 2, 2);
  gtk_box_pack_start(GTK_BOX(dialog_vbox), hbox, TRUE, TRUE, 2);

  gtk_box_pack_start(GTK_BOX(hbox), tree, TRUE, TRUE, 2);
  gtk_box_pack_start(GTK_BOX(hbox), notebook, TRUE, TRUE, 2);

  gtk_widget_show (notebook);

  if (rubrica_preferences_there_are_errors())
    {
      gtk_window_set_modal (GTK_WINDOW (preferences_dialog), FALSE);
      rubrica_dialog_error_loading_preferences_keys();      
      gtk_window_set_modal (GTK_WINDOW (preferences_dialog), TRUE);      
    }

  g_object_set_data (G_OBJECT (preferences_dialog), "preferences_dialog", 
		     preferences_dialog);
  g_object_set_data (G_OBJECT (preferences_dialog), "treeview", tree);
  g_object_set_data (G_OBJECT (preferences_dialog), "notebook", notebook);
  g_object_set_data (G_OBJECT (preferences_dialog), "tooltips", tooltips);

  return preferences_dialog;
}


GtkWidget *
rubrica_preferences_build_notebook_info_page(gchar *frame_label, gchar *pixfile, gchar *str)
{
  GtkWidget *frame;
  GtkWidget *framebox;
  GtkWidget *imagebox;
  GtkWidget *image;
  GtkWidget *label;

  frame = rubrica_ui_frame_new(frame_label);
  framebox = rubrica_ui_default_box_new(VBOX);
  gtk_container_add (GTK_CONTAINER (frame), framebox);
  
  imagebox = rubrica_ui_default_box_new(HBOX);
  gtk_box_pack_start(GTK_BOX(framebox), imagebox, FALSE, FALSE, 2);
  
  image = rubrica_ui_image_new(pixfile);
  gtk_box_pack_start(GTK_BOX(imagebox), image, FALSE, FALSE, 2);

  label = rubrica_ui_label_new(str);
  gtk_box_pack_start(GTK_BOX(framebox), label, FALSE, FALSE, 2);

  return frame;
}


GtkWidget*
rubrica_preferences_build_notebook_list_page(GConfClient *client, gchar *frame_label, 
					     gchar *str, RubricaTreeType type)
{
  GtkWidget *frame;

  GtkTreeModel *model;
  GtkWidget *list;
  GtkWidget *box_frame;
  GtkWidget *box_label;
  GtkWidget *label;
  GtkWidget *scrollwin;
  GtkWidget *sep;
  
  
  frame = rubrica_ui_frame_new(frame_label);
  box_frame = gtk_vbox_new(FALSE, 2);
  gtk_container_add(GTK_CONTAINER(frame), box_frame);
  gtk_widget_show(box_frame);
  
  model = rubrica_preferences_create_list_model(client, type);
  list  = rubrica_preferences_create_list_view_with_model(model, type);

  g_object_unref(G_OBJECT(model));
  
  scrollwin = rubrica_ui_scrolled_window_new();

  sep = gtk_hseparator_new();
  gtk_widget_show(sep);

  box_label = gtk_hbox_new(FALSE, 2);
  label = gtk_label_new(str);
  gtk_box_pack_start(GTK_BOX(box_label), label, FALSE, FALSE, 5);
  gtk_widget_show(box_label);
  gtk_widget_show(label);

  gtk_box_pack_start(GTK_BOX(box_frame), box_label, FALSE, FALSE, 5);
  gtk_box_pack_start(GTK_BOX(box_frame), sep,  FALSE, FALSE, 5);  
  gtk_box_pack_start(GTK_BOX(box_frame), scrollwin,  TRUE, TRUE, 5);  
  gtk_container_add(GTK_CONTAINER(scrollwin), list);

  return frame;
}

int rubrica_preferences_file_info(GConfClient *client, gchar *frame_label)
{
  GtkWidget *frame;
  gint page;
  gchar *str;

  str = N_("In file pages you can customize the default folder\n"
	   "that rubrica will use to save addressbooks, you can set the\n"
	   "default addressbook that rubrica will load when start,\n"
	   "you can choose backup type,can choose to use autosave\n"
	   "and other...");

  frame = rubrica_preferences_build_notebook_info_page(frame_label, "file-info.png", str);
  
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, NULL); 
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), frame);

  return page;
}

int rubrica_preferences_general_info(GConfClient *client, gchar *frame_label)
{
  GtkWidget *frame;
  gint page;
  gchar *str;

  str = N_("In general pages you can choose how cards will be\n" 
	   "ordered (alphabetic order or by creation date),\n"
	   "increasing order or decreasing order. Can set the\n"
	   "search rules, some decoratives properties");

  frame = rubrica_preferences_build_notebook_info_page(frame_label, "general-info.png", str);

  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, NULL); 
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), frame);

  return page;
}

int rubrica_preferences_view_info(GConfClient *client, gchar *frame_label)
{
  GtkWidget *frame;
  gint page;
  gchar *str;

  str = N_("In view pages you can choose what rubrica will\n"
	   "show to you in cards/account window and data window.\n"
	   "Can select the card's columns to show.\nCan select the" 
	   "card's data to show.");

  frame = rubrica_preferences_build_notebook_info_page(frame_label, "view-info.png", str); 

  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, NULL); 
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), frame);

  return page;
}

int rubrica_preferences_crypto_info(GConfClient *client, gchar *frame_label)
{
  GtkWidget *frame;
  gint page;
  gchar *str;

  str = N_("In cryptographic pages you can choose to protect your data\n"
	   "using a cryptographic routine. Some crypt algorithms\n"
	   "are available (TODO: list here)");
    
  frame = rubrica_preferences_build_notebook_info_page(frame_label, "crypto-info.png", str);
  
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, NULL); 
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), frame);

  return page;
}

int rubrica_preferences_trans_info(GConfClient *client, gchar *frame_label)
{
  GtkWidget *frame;
  gint page;
  gchar *str;
 
  str = N_("In translation pages you can choose if rubrica must use\n"
	   "one default dictionary (Italian or English) or can build\n"
	   "your own dictionary. Dictionary is used in rubrica preview\n"
	   "to show card's fields in your native language.\n");
    
  frame = rubrica_preferences_build_notebook_info_page(frame_label, "translation-info.png",
						       str);

  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, NULL); 
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), frame);

  return page;
}

int rubrica_not_implemented(GConfClient *client, gchar *frame_label)
{
  GtkWidget *frame;
  gint page;
  gchar *str;

  str = N_("Sorry, this features is not yet implemented ;-)\n");
    
  frame = rubrica_preferences_build_notebook_info_page(frame_label, "info.png", str);

  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, NULL); 
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), frame);

  return page;
}


int 
rubrica_preferences_default(GConfClient *client, gchar *frame_label)
{
  GtkWidget *file_frame;
  gint page;

  GtkWidget *box_file;
  GtkWidget *box_addbook;
  GtkWidget *box_folder;

  GtkWidget *show_frame;
  GtkWidget *addbook_frame;
  GtkWidget *folder_frame;

  GtkWidget *check_path;
  GtkWidget *check_addbook;
  GtkWidget *check_folder;

  GtkWidget *fileentry_addbook;
  GtkWidget *fileentry_folder;
  GtkWidget *entry_addbook;
  GtkWidget *entry_folder;

  gchar *str;


  file_frame = rubrica_ui_frame_new(frame_label);

  /*    SHOW PATH 
	show path check button
  */
    
  box_file = rubrica_ui_box_new(VBOX, FALSE, 0, 5);
  gtk_container_add (GTK_CONTAINER (file_frame), box_file);

  show_frame =  rubrica_ui_frame_new(_("Show"));
  gtk_box_pack_start (GTK_BOX (box_file), show_frame, FALSE, FALSE, 2);

  check_path = rubrica_ui_check_button_new(_("_Show addressbook's path"));
  gtk_tooltips_set_tip(tooltips, check_path, _("Show the path of current addressbook "), NULL);
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW, check_path);
  gtk_container_add(GTK_CONTAINER(show_frame), check_path);

  rubrica_preferences_configure_check(client, check_path, RUBRICA_KEY_SHOW); 


  /*    -----------------------------------------------------------------------
	load address book at rubrica start
	use a default folder to save addressbooks

	- check_addbook   
	    - true:  load addressbook at start
	    - false: start with void addressbook

	    - entry: addressbook file name
	
	- check_folder
	    - true:  use the setted directory as default folder
	    - false  save addressbook in current directory

	    - entry: directory name
	-----------------------------------------------------------------------
  */

  /*    ADDRESS BOOK
   */
  addbook_frame = rubrica_ui_frame_new(_("Default address book"));
  gtk_box_pack_start (GTK_BOX (box_file), addbook_frame, FALSE, FALSE, 2);

  box_addbook = rubrica_ui_default_box_new(VBOX);
  gtk_container_add (GTK_CONTAINER (addbook_frame), box_addbook);

  /*    CHECK BUTTON
	CHECK ADDRESS BOOK
   */
  check_addbook = rubrica_ui_check_button_new(_("_Load this addressbook at start"));
  gtk_box_pack_start (GTK_BOX (box_addbook), check_addbook, FALSE, FALSE, 0);
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_HAVE_BOOK, check_addbook);

  /*    GNOME FILE ENTRY
	ADDRESS BOOK
  */
  fileentry_addbook = gnome_file_entry_new ("history_addressbook", NULL);
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_BOOK, fileentry_addbook);
  g_object_set_data (G_OBJECT (check_addbook), RUBRICA_KEY_BOOK, fileentry_addbook);

  gtk_box_pack_start (GTK_BOX (box_addbook), fileentry_addbook, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (fileentry_addbook), 2);
  gnome_file_entry_set_modal (GNOME_FILE_ENTRY (fileentry_addbook), TRUE);
  gtk_widget_show (fileentry_addbook);

  /*    FILE ENTRY
	ADDRESS BOOK
  */  
  entry_addbook = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (fileentry_addbook));
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_addbook", entry_addbook);

  if (gconf_client_get_bool(client, RUBRICA_KEY_HAVE_BOOK, NULL))
    str = g_strdup(gconf_client_get_string(client, RUBRICA_KEY_BOOK, NULL));
  else
    str = g_strdup_printf("%s/.rubrica/rubrica.rub", g_get_home_dir());      
  
  gtk_entry_set_text (GTK_ENTRY (entry_addbook), str);
  gtk_widget_show (entry_addbook);
  g_free(str);  

  /*      GConf settings
   */
  rubrica_preferences_configure_checked_entry(client, check_addbook, fileentry_addbook, 
					      entry_addbook, RUBRICA_KEY_HAVE_BOOK, 
					      RUBRICA_KEY_BOOK);

  /*    FOLDER
   */
  folder_frame = rubrica_ui_frame_new(_("Default folder"));
  gtk_box_pack_start (GTK_BOX (box_file), folder_frame, FALSE, FALSE, 2);

  box_folder = rubrica_ui_default_box_new(VBOX);
  gtk_container_add (GTK_CONTAINER (folder_frame), box_folder);

  /*    CHECK FOLDER
   */
  check_folder =rubrica_ui_check_button_new(_("_Save addressbooks in this"
					       " folder by default"));
  gtk_box_pack_start (GTK_BOX (box_folder), check_folder, FALSE, FALSE, 0);
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_HAVE_FOLDER, check_folder);

  /*    GNOME FILE ENTRY
	FOLDER
  */
  fileentry_folder = gnome_file_entry_new ("history_folder", _("Choose a folder"));
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_FOLDER, fileentry_folder);

  gtk_box_pack_start (GTK_BOX (box_folder), fileentry_folder, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (fileentry_folder), 2);
  gnome_file_entry_set_modal (GNOME_FILE_ENTRY (fileentry_folder), TRUE);
  gtk_widget_show (fileentry_folder);

  /*    FILE ENTRY
	FOLDER
  */ 
  entry_folder = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (fileentry_folder));
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_folder", entry_folder);
  gtk_widget_show (entry_folder);

  if (gconf_client_get_bool(client, RUBRICA_KEY_HAVE_FOLDER, NULL))
    str = g_strdup(gconf_client_get_string(client, RUBRICA_KEY_FOLDER, NULL));
  else
    str = g_strdup_printf("%s/.rubrica/", g_get_home_dir());  
    
  gtk_entry_set_text (GTK_ENTRY (entry_folder), str);
  g_free(str);  

  /*    GConf settings
  */
  rubrica_preferences_configure_checked_entry(client,
					      check_folder, fileentry_folder, entry_folder,  
					      RUBRICA_KEY_HAVE_FOLDER, RUBRICA_KEY_FOLDER);


  /*    SHOW PATH CALLBACK
  */
  g_signal_connect (G_OBJECT (check_path), "toggled",
		    G_CALLBACK (on_check_button_toggled), RUBRICA_KEY_SHOW);

  /*    LOAD DEFAULT ADDRESS BOOK CALLBACKS
  */
  g_signal_connect (G_OBJECT (check_addbook), "toggled",
		    G_CALLBACK (on_check_button_toggled), RUBRICA_KEY_HAVE_BOOK);
  g_signal_connect (G_OBJECT (entry_addbook), "changed",
		    G_CALLBACK (on_entry_changed), RUBRICA_KEY_BOOK);
  
  /*    USE DEFAULT FOLDER CALLBACKS
  */
  g_signal_connect (G_OBJECT (check_folder), "toggled",
		    G_CALLBACK (on_check_button_toggled), RUBRICA_KEY_HAVE_FOLDER);
  g_signal_connect (G_OBJECT (entry_folder), "changed",
		    G_CALLBACK (on_entry_changed), RUBRICA_KEY_FOLDER);


  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), file_frame, NULL); 
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), file_frame);
  
  return page;
}


int rubrica_preferences_file_settings(GConfClient *client, gchar *frame_label)
{
  GtkWidget *frame;
  GtkWidget *vbox;
  gint page;

  GtkWidget *box_backup; 
  GtkWidget *box_radio_backup;
  GtkWidget *box_main_compress;
  GtkWidget *box_compression;
  GtkWidget *box_compression_rate;
  GtkWidget *box_autosave;
  GtkWidget *box_check_autosave;
  GtkWidget *box_spin_autosave;

  GtkWidget *backup_frame;
  GtkWidget *compress_frame;
  GtkWidget *autosave_frame;

  GSList *radio_backup_group = NULL;
  GtkWidget *radio_backup_inc;
  GtkWidget *radio_backup_classic;

  GtkWidget *check_backup;
  GtkWidget *check_compress;
  GtkWidget *check_autosave;

  GtkWidget *label_compress_rate;
  GtkObject *spin_rate_adj;
  GtkWidget *spin_rate;

  GtkWidget *label_autosave1;
  GtkWidget *label_autosave2;
  GtkObject *spin_autosave_adj;
  GtkWidget *spin_autosave;


  frame = rubrica_ui_frame_new(frame_label);
  vbox  = rubrica_ui_default_box_new(VBOX);
  gtk_container_add (GTK_CONTAINER (frame), vbox);
  
  /*    Backup:
	- do backup before overwrite 

	default: don't do backup

	CHECK BUTTON
	BACKUP ALWAYS
  */ 
  backup_frame = rubrica_ui_frame_new(_("Backup"));
  gtk_box_pack_start (GTK_BOX (vbox), backup_frame, FALSE, FALSE, 2);

  box_backup = rubrica_ui_box_new(VBOX, TRUE, 0, 2);
  gtk_container_add (GTK_CONTAINER (backup_frame), box_backup);

  /*    CHECK BUTTON BACKUP 
  */
  check_backup = rubrica_ui_check_button_new(_("_Make backup of previous file "
						"before overwrite"));
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_BACKUP, check_backup);
  gtk_box_pack_start (GTK_BOX (box_backup), check_backup, TRUE, TRUE, 0);

  /*    RADIO BACKUP INCREMENT
  */
  box_radio_backup = rubrica_ui_box_new(HBOX, FALSE, 0, 2);
  gtk_box_pack_start (GTK_BOX (box_backup), box_radio_backup, FALSE, FALSE, 0);
  g_object_set_data (G_OBJECT (preferences_dialog), "box_radio_backup", box_radio_backup);

  radio_backup_inc = gtk_radio_button_new_with_mnemonic (radio_backup_group,
						      _("in_cremental backup"));
  radio_backup_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_backup_inc));

  g_object_set_data(G_OBJECT (preferences_dialog), "inc_bak", radio_backup_inc);

  gtk_box_pack_start (GTK_BOX (box_radio_backup), radio_backup_inc, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, radio_backup_inc, 
			_("Example: The backup of addressbook.rub "
			  "file will be addressbook.rub1, if "
			  "addressbook.rub1 exist then backup "
			  "will be addressbook.rub2, and so on."), NULL);
  gtk_widget_show (radio_backup_inc);

  /*    RADIO BACKUP CLASSIC
  */
  radio_backup_classic = gtk_radio_button_new_with_mnemonic (radio_backup_group, 
							  _("cl_assic backup"));
  radio_backup_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_backup_classic));
  g_object_set_data (G_OBJECT (preferences_dialog),"bak_bak", radio_backup_classic);

  gtk_box_pack_start (GTK_BOX (box_radio_backup), radio_backup_classic, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, radio_backup_classic, 
			_("The backup of addressbook.rub will "
			  "be addressbook.bak"), NULL);
  gtk_widget_show (radio_backup_classic);

  /* GConf settings
   */
  rubrica_preferences_configure_check_radio(client,
					    check_backup, radio_backup_inc, 
					    radio_backup_classic, 
					    RUBRICA_KEY_BACKUP, RUBRICA_KEY_BACKUP_TYPE_INC);

  /*    Compress addressbook:
	- compression check button        
	- compression rate spin button

	default: not compress, compression rate: 0

	CHECK BUTTON
	COMPRESS ADDRESSBOOK FILE
  */
  compress_frame = rubrica_ui_frame_new(_("Compression"));
  gtk_box_pack_start (GTK_BOX (vbox), compress_frame, FALSE, FALSE, 2);

  box_main_compress = rubrica_ui_box_new(VBOX, TRUE, 0, 2);
  gtk_container_add (GTK_CONTAINER (compress_frame), box_main_compress);

  box_compression = rubrica_ui_box_new(HBOX, TRUE, 0, 2);
  gtk_box_pack_start (GTK_BOX (box_main_compress), box_compression, FALSE, FALSE, 0);

  /*    CHECK BUTTON COMPRESS ADDRESSBOOK FILE
  */
  check_compress = rubrica_ui_check_button_new(_("Com_press addressbook"));
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_COMPRESS, check_compress);
  gtk_box_pack_start (GTK_BOX (box_compression), check_compress, TRUE, TRUE, 0);

  box_compression_rate = rubrica_ui_box_new(HBOX, FALSE, 0, 2);
  gtk_box_pack_end(GTK_BOX(box_main_compress), box_compression_rate, FALSE, FALSE, 0);
  g_object_set_data (G_OBJECT (check_compress), "spin_box", box_compression_rate);

  label_compress_rate = gtk_label_new (_("Compression rate:"));
  gtk_box_pack_start(GTK_BOX(box_compression_rate), label_compress_rate, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_compress_rate), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_compress_rate), 3, 0);
  gtk_widget_show (label_compress_rate);

  /*    SPIN BUTTON
	COMPRESSION RATE
  */  
  spin_rate_adj = gtk_adjustment_new (0, 0, 9, 1, 1, 1);
  spin_rate = gtk_spin_button_new (GTK_ADJUSTMENT (spin_rate_adj), 1, 0);
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_RATE, spin_rate);

  gtk_box_pack_start (GTK_BOX (box_compression_rate), spin_rate, FALSE, FALSE, 5);
  gtk_tooltips_set_tip (tooltips, spin_rate, _("0 not compressed, "
					       "9 max compression rate"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spin_rate), TRUE);
  gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (spin_rate), FALSE);
  gtk_widget_show (spin_rate);

  /*    GConf settings
   */
  rubrica_preferences_configure_spin(client, check_compress, spin_rate,  
				     RUBRICA_KEY_COMPRESS, RUBRICA_KEY_RATE);

  /*    Automatic save:
	- autosave check button        
	- autosave spin button

	default: autosave: no, time elapsed: 0

	CHECK BUTTON
	AUTOSAVE ADDRESSBOOK FILE
  */
  autosave_frame = rubrica_ui_frame_new(_("Autosave"));
  gtk_box_pack_start (GTK_BOX (vbox), autosave_frame, FALSE, FALSE, 2);

  box_autosave = rubrica_ui_box_new(VBOX, FALSE, 0, 2);
  gtk_container_add (GTK_CONTAINER (autosave_frame), box_autosave);

  box_check_autosave = rubrica_ui_box_new(HBOX, FALSE, 0, 2);
  gtk_box_pack_start (GTK_BOX (box_autosave), box_check_autosave, FALSE, FALSE, 0);

  /*    CHECK BUTTON AUTOSAVE ADDRESSBOOK FILE
  */
  check_autosave = rubrica_ui_check_button_new(_("_enable autosave"));
  g_object_set_data(G_OBJECT (preferences_dialog), RUBRICA_KEY_AUTOSAVE, check_autosave);
  gtk_box_pack_start (GTK_BOX (box_check_autosave), check_autosave, TRUE, TRUE, 0);

  box_spin_autosave = rubrica_ui_box_new(HBOX, FALSE, 0, 2);
  g_object_set_data(G_OBJECT (check_autosave), "spin_box", box_spin_autosave);

  gtk_box_pack_start (GTK_BOX (box_autosave), box_spin_autosave, FALSE, FALSE, 0);

  label_autosave1 = gtk_label_new (_("Save addressbooks ever"));
  gtk_box_pack_start (GTK_BOX (box_spin_autosave), label_autosave1, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label_autosave1), 3, 0);
  gtk_widget_show (label_autosave1);

  /*    SPIN BUTTON
	SAVE EVERY xx MINUTES
  */  
  spin_autosave_adj = gtk_adjustment_new (0, 0, 100, 1, 10, 10);
  spin_autosave = gtk_spin_button_new (GTK_ADJUSTMENT (spin_autosave_adj), 1, 0);
  gtk_box_pack_start (GTK_BOX (box_spin_autosave), spin_autosave, FALSE, FALSE, 0);
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_WAIT_TIME, spin_autosave);
  gtk_widget_show (spin_autosave);

  label_autosave2 = gtk_label_new (_("minutes"));
  gtk_misc_set_padding (GTK_MISC (label_autosave2), 5, 0);
  gtk_box_pack_start (GTK_BOX (box_spin_autosave), label_autosave2, FALSE, FALSE, 0);
  gtk_widget_show (label_autosave2);

  /*    GConf settings
   */
  rubrica_preferences_configure_spin(client,
				     check_autosave, spin_autosave, 
				     RUBRICA_KEY_AUTOSAVE, RUBRICA_KEY_WAIT_TIME);

  gconf_client_notify_add(client, RUBRICA_KEY_WAIT_TIME, 
			  rubrica_preferences_notify_autosave_time_changes, 
			  spin_autosave, NULL, NULL);

  /*    BACKUP CALLBACKS
  */
  g_signal_connect (G_OBJECT (check_backup), "toggled",
		    G_CALLBACK (on_check_button_toggled), RUBRICA_KEY_BACKUP);

  g_signal_connect (G_OBJECT (radio_backup_inc), "toggled",
		    G_CALLBACK (on_radio_button_toggled), RUBRICA_KEY_BACKUP_TYPE_INC);
  g_signal_connect (G_OBJECT (radio_backup_classic), "toggled",
		    G_CALLBACK (on_radio_button_toggled), RUBRICA_KEY_BACKUP_TYPE_BAK);

  /*    COMPRESS CALLBACKS
  */
  g_signal_connect (G_OBJECT (check_compress), "toggled",
		    G_CALLBACK (on_check_button_toggled), RUBRICA_KEY_COMPRESS);
  g_signal_connect (G_OBJECT (spin_rate), "activate",
		    G_CALLBACK (on_spin_activate), RUBRICA_KEY_RATE);
  g_signal_connect (G_OBJECT (spin_rate), "changed",
		    G_CALLBACK (on_spin_activate), RUBRICA_KEY_RATE);

  /*    AUTOSAVE CALLBACKS
  */
  g_signal_connect (G_OBJECT (check_autosave), "toggled",
		    G_CALLBACK (on_check_button_toggled), RUBRICA_KEY_AUTOSAVE);
  g_signal_connect (G_OBJECT (spin_autosave), "activate",
		    G_CALLBACK (on_spin_activate), RUBRICA_KEY_WAIT_TIME);
  g_signal_connect (G_OBJECT (spin_autosave), "changed",
		    G_CALLBACK (on_spin_activate), RUBRICA_KEY_WAIT_TIME);


  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, NULL); 
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), frame);

  return page;
}


int rubrica_preferences_search(GConfClient *client, gchar *frame_label)
{
  GtkWidget *general_frame;
  gint page;

  GtkWidget *box_general;
  GtkWidget *box_order;
  GtkWidget *box_search;  

  GtkWidget *table1;
  GtkWidget *search_table;
/*
  GSList *opt_ordine_group = NULL;
  GtkWidget *radio_alpha;
  GtkWidget *radio_date;
*/

  GSList *opt_string_search_group = NULL;
  GtkWidget *radio_complete;
  GtkWidget *radio_incomplete;

  GtkWidget *ordering_frame;
  GtkWidget *search_frame;

  GtkWidget *direction;
  GtkWidget *check_case_search;
//  GtkWidget *label_show;
  GtkWidget *label_search; 
  GtkWidget *label_search_menu;

  GtkWidget *combo_search;
  GList *combo_search_items = NULL;
  GtkWidget *combo_entry_search;

  GtkWidget *sort_label;
  GtkWidget *sort_menu;
  RubricaOptionType sort_option[] = {
    {"", N_("in alphabetic order"), NO_GROUP},
    {"", N_("by creation date"),    NO_GROUP},
    {"", N_("by last change date"), NO_GROUP},
    {NULL}
  };

  general_frame = rubrica_ui_frame_new(frame_label);
  box_general = rubrica_ui_box_new(VBOX, FALSE, 0, 2);
  gtk_container_add (GTK_CONTAINER (general_frame), box_general);

  /*    Ordering:
	- increasing   (true)
	- decreasing   (false)

	default: increasing 
  */
  ordering_frame = rubrica_ui_frame_new(_("Ordering"));
  gtk_box_pack_start (GTK_BOX (box_general), ordering_frame, FALSE, FALSE, 2);

  box_order = rubrica_ui_box_new(VBOX, TRUE, 0, 2);
  gtk_container_add (GTK_CONTAINER (ordering_frame), box_order);

  table1 = gtk_table_new (2, 3, TRUE);
  gtk_widget_show (table1);

  gtk_box_pack_start (GTK_BOX (box_order), table1, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table1), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table1), 5);

  sort_label = rubrica_ui_tabled_label_new(table1, _("Sort cards"), 0, 1, 0, 1);
//  gtk_misc_set_padding (GTK_MISC (label_show), 5, 0);

  /* 
     CHECK BUTTON: INCREASE
  */
  direction = rubrica_ui_tabled_check_new(table1, _("_Sort is ascending"), 0, 2, 1, 2);
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_SORT_DIRECTION, direction);
  gtk_container_set_border_width (GTK_CONTAINER (direction), 2);
  gtk_tooltips_set_tip (tooltips, direction, _("Uncheck for descending sort"), NULL);

  /*    GConf settings
   */
  rubrica_preferences_configure_check(client, direction, RUBRICA_KEY_SORT_DIRECTION); 

  /*        SORT MENU

            - SORT BY DATE (CREATION, LAST CHANGE)
	    - SORT ALPHABETICALLY

	    default: alphabetic order
  */
  sort_menu = rubrica_ui_option_menu_new(sort_option);
  gtk_table_attach_defaults (GTK_TABLE (table1), sort_menu, 2, 3, 0, 1);
  rubrica_preferences_configure_option_menu(client, sort_menu, RUBRICA_KEY_SORT_TYPE);

/*
  radio_date = gtk_radio_button_new_with_mnemonic (opt_ordine_group, _("by _creation date"));
  opt_ordine_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_date));
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_DATE_ORDER, radio_date);
  gtk_table_attach_defaults (GTK_TABLE (table1), radio_date, 2, 3, 0, 1);
  gtk_widget_show (radio_date);

  radio_alpha = gtk_radio_button_new_with_mnemonic (opt_ordine_group, 
                                                    _("in _alphabetic order"));
  opt_ordine_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_alpha));
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_ALPHA_ORDER, radio_alpha);
  gtk_table_attach_defaults (GTK_TABLE (table1), radio_alpha, 1, 2, 0, 1);
  gtk_widget_show (radio_alpha);

  // *   GConf settings

  rubrica_preferences_configure_radio(client, 2, 
				      radio_alpha, RUBRICA_KEY_ALPHA_ORDER,
				      radio_date, RUBRICA_KEY_DATE_ORDER);
  */

  search_frame = rubrica_ui_frame_new(_("Search"));
  gtk_box_pack_start (GTK_BOX (box_general), search_frame, FALSE, FALSE, 2);

  box_search = rubrica_ui_box_new(VBOX, TRUE, 0, 2);
  gtk_container_add (GTK_CONTAINER (search_frame), box_search);

  search_table = rubrica_ui_table_new (3, 3, TRUE, 2, 2, 5);
  gtk_box_pack_start (GTK_BOX (box_search), search_table, TRUE, TRUE, 0);

  label_search = rubrica_ui_tabled_label_new(search_table, _("Search on:"), 0, 1, 0, 1);
  gtk_misc_set_padding (GTK_MISC (label_search), 4, 0);


  /*      CHECK BUTTON
	  
          SEARCH CASE SENSITIVE
  */
  check_case_search = rubrica_ui_tabled_check_new(search_table,
						   _("Default _search is case sensitive"),
						   0, 2, 1, 2);
  g_object_set_data (G_OBJECT (preferences_dialog), "check_case_search",check_case_search);
  gtk_container_set_border_width (GTK_CONTAINER (check_case_search), 2);
  gtk_tooltips_set_tip (tooltips, check_case_search, 
			_("Uncheck for case insensitive search"), NULL);

  /*        RADIO BUTTONS
	    
            - SEARCH ON COMPLETE STRING
	    - SEARCH ON INCOMPLETE STRING     

	    default: search in complete string
   */
  radio_complete = gtk_radio_button_new_with_mnemonic (opt_string_search_group, 
						    _("co_mplete string"));
  opt_string_search_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_complete));
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_COMPLETE, radio_complete);

  radio_incomplete = gtk_radio_button_new_with_mnemonic (opt_string_search_group, 
						      _("_incomplete string"));
  opt_string_search_group = gtk_radio_button_group(GTK_RADIO_BUTTON(radio_incomplete));
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_INCOMPLETE, 
		       radio_incomplete);

  gtk_table_attach_defaults (GTK_TABLE (search_table), radio_complete,   1, 2, 0, 1);
  gtk_table_attach_defaults (GTK_TABLE (search_table), radio_incomplete, 2, 3, 0, 1);
  gtk_widget_show (radio_complete);
  gtk_widget_show (radio_incomplete);

  /*   GConf settings
  */
  rubrica_preferences_configure_radio(client, 2,
				      radio_complete, RUBRICA_KEY_COMPLETE,
				      radio_incomplete, RUBRICA_KEY_INCOMPLETE);

  label_search_menu = rubrica_ui_tabled_label_new(search_table, _("Default Search on: "),
						   0, 1, 2, 3);
  gtk_misc_set_padding (GTK_MISC (label_search_menu), 4, 0);


  /*    COMBO SEARCH -- Display all searchable data --
  */
  combo_search = gtk_combo_new ();
  g_object_set_data (G_OBJECT(preferences_dialog), RUBRICA_KEY_SEARCH, combo_search);
  gtk_table_attach_defaults (GTK_TABLE (search_table), combo_search, 1, 2, 2, 3);
  gtk_widget_show (combo_search);

  gtk_combo_set_value_in_list (GTK_COMBO (combo_search), TRUE, FALSE);  
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_CARD);
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_FIRST_NAME);
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_LAST_NAME);
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_PROFESSION);
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_CITY);
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_COUNTRY);
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_WEB_ADDRESS);
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_EMAIL_ADDRESS);
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_TELEPHONE);
  gtk_combo_set_popdown_strings (GTK_COMBO (combo_search), combo_search_items);
  g_list_free (combo_search_items);
  
  combo_entry_search = GTK_COMBO (combo_search)->entry;
  g_object_set_data(G_OBJECT (preferences_dialog), "entry_search", combo_entry_search);
  gtk_widget_show (combo_entry_search);

  /*    GConf settings
   */
  rubrica_preferences_configure_combo_entry(client, combo_entry_search, RUBRICA_KEY_SEARCH);


  /*    INCREASE CALLBACK
   */
  g_signal_connect (G_OBJECT (direction), "toggled", 
		    G_CALLBACK (on_check_button_toggled), RUBRICA_KEY_SORT_DIRECTION); 

  /*    ORDERING TYPE CALLBACKS
   */
  g_signal_connect (G_OBJECT (sort_menu), "changed", 
		    G_CALLBACK (on_option_menu_changed), RUBRICA_KEY_SORT_TYPE); 

  /*
  g_signal_connect (G_OBJECT (radio_alpha), "toggled",
		    G_CALLBACK (on_radio_button_toggled), RUBRICA_KEY_ALPHA_ORDER);
  g_signal_connect (G_OBJECT (radio_date), "toggled",
		    G_CALLBACK (on_radio_button_toggled), RUBRICA_KEY_DATE_ORDER); 
  */
  /*    SEARCH CALLBACS
  */
  g_signal_connect (G_OBJECT (check_case_search), "toggled",
		    G_CALLBACK (on_check_button_toggled), RUBRICA_KEY_SENSITIVE);

  g_signal_connect (G_OBJECT (radio_complete), "toggled",
		    G_CALLBACK (on_radio_button_toggled), RUBRICA_KEY_COMPLETE);
  g_signal_connect (G_OBJECT (radio_incomplete), "toggled",
		    G_CALLBACK (on_radio_button_toggled), RUBRICA_KEY_INCOMPLETE);

  g_signal_connect (G_OBJECT (combo_entry_search), "changed",
		    G_CALLBACK (on_entry_search_changed), RUBRICA_KEY_SEARCH); 


  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), general_frame, NULL); 
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), general_frame);

  return page;
}



int rubrica_preferences_misc(GConfClient *client, gchar *frame_label)
{
  GtkWidget *general_frame;
  gint page;

  GtkWidget *box_general;
  GtkWidget *box_size;
  GtkWidget *box_width;
  GtkWidget *box_length;
  GtkWidget *box_exit;
  GtkWidget *box_tooltips;
  GtkWidget *box_toolbar;

  GtkWidget *size_frame;
  GtkWidget *exit_frame;
  GtkWidget *tooltips_frame;
  GtkWidget *toolbar_frame;

  GtkWidget *check_exit;
  GtkWidget *check_tooltips;

  GtkObject *spin_width_adj;
  GtkWidget *spin_width;
  GtkObject *spin_length_adj;
  GtkWidget *spin_length;

  GtkWidget *label_width;
  GtkWidget *label_length; 

  GtkWidget *option_label;
  GtkWidget *option_menu;
  RubricaOptionType toolbar_option[] = {
    {"", N_("both text and icons"), NO_GROUP},
    {"", N_("only icons"), NO_GROUP},
    {"", N_("only text"),  NO_GROUP},
    {"", N_("both text and icons alongside each other"), NO_GROUP},
    {NULL}
  };
  
  general_frame = rubrica_ui_frame_new(frame_label);
  box_general = rubrica_ui_box_new(VBOX, FALSE, 0, 2);
  gtk_container_add (GTK_CONTAINER (general_frame), box_general);

  /*     WINDOW SIZE FRAME
  */
  size_frame = rubrica_ui_frame_new(_("Application dimension"));
  gtk_box_pack_start (GTK_BOX (box_general), size_frame, FALSE, FALSE, 2);
  
  box_size   = rubrica_ui_box_new(VBOX, FALSE, 0, 2);
  box_width  = rubrica_ui_box_new(HBOX, FALSE, 0, 2);
  box_length = rubrica_ui_box_new(HBOX, FALSE, 0, 2);

  gtk_container_add (GTK_CONTAINER (size_frame), box_size);
  gtk_box_pack_start(GTK_BOX (box_size), box_width,  FALSE, TRUE, 2);
  gtk_box_pack_start(GTK_BOX (box_size), box_length, FALSE, TRUE, 2);

  /* lunghezza */
  label_width =  gtk_label_new (_("Width dimension:"));
  gtk_misc_set_alignment (GTK_MISC (label_width), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_width), 5, 0);
  gtk_widget_show (label_width);

  spin_width_adj = gtk_adjustment_new (0, 0, 1200, 1, 10, 10);
  spin_width = gtk_spin_button_new (GTK_ADJUSTMENT (spin_width_adj), 1, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spin_width), TRUE);
  gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (spin_width), FALSE);
  gtk_widget_show (spin_width);

  gtk_box_pack_start(GTK_BOX(box_width), label_width, FALSE, FALSE, 0);
  gtk_box_pack_start(GTK_BOX(box_width), spin_width, FALSE, FALSE, 0);
  g_object_set_data(G_OBJECT (preferences_dialog), "spin_width", spin_width);

  /* altezza */
  label_length =  gtk_label_new (_("Length dimension:"));
  gtk_misc_set_alignment (GTK_MISC (label_length), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_length), 5, 0);
  gtk_widget_show (label_length);

  spin_length_adj = gtk_adjustment_new (0, 0, 800, 1, 10, 10);
  spin_length = gtk_spin_button_new (GTK_ADJUSTMENT (spin_length_adj), 1, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spin_length), TRUE);
  gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (spin_length), FALSE);
  gtk_widget_show (spin_length);

  gtk_box_pack_start(GTK_BOX(box_length), label_length, FALSE, FALSE, 0);
  gtk_box_pack_start(GTK_BOX(box_length), spin_length, FALSE, FALSE, 0);
  g_object_set_data(G_OBJECT (preferences_dialog), "spin_length", spin_length);

  rubrica_preferences_configure_size_spin(client, spin_width,  RUBRICA_KEY_WIDTH); 
  rubrica_preferences_configure_size_spin(client, spin_length, RUBRICA_KEY_LENGTH); 


  /* EXIT FRAME
   */
  exit_frame = rubrica_ui_frame_new(_("Exit"));
  gtk_box_pack_start (GTK_BOX (box_general), exit_frame, FALSE, FALSE, 2);

  box_exit = rubrica_ui_box_new(HBOX, TRUE, 0, 2);
  gtk_container_add (GTK_CONTAINER (exit_frame), box_exit);

  /*    CHECK BUTTON
	
	EXIT

	default: ask before quit
  */
  check_exit = rubrica_ui_check_button_new(_("E_xit from rubrica without confirm"));
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_EXIT, check_exit);
  gtk_box_pack_start (GTK_BOX (box_exit), check_exit, TRUE, TRUE, 0);

  /*  	GConf settings
  */
  rubrica_preferences_configure_check(client, check_exit, RUBRICA_KEY_EXIT);


  /*    ENABLE TOOLTIPS
	show tooltips -- default: true
  */
  tooltips_frame = rubrica_ui_frame_new(_("Tooltips"));
  g_object_set_data (G_OBJECT (preferences_dialog), "tooltips_frame", tooltips_frame);
  gtk_box_pack_start (GTK_BOX (box_general), tooltips_frame, FALSE, FALSE, 2);  

  box_tooltips = rubrica_ui_box_new(HBOX, TRUE, 0, 2);
  gtk_container_add (GTK_CONTAINER (tooltips_frame), box_tooltips);

  /*    CHECK BUTTON SHOW TIPS
  */
  check_tooltips = rubrica_ui_check_button_new(_("Enable _Tooltips"));
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_TOOLTIPS, check_tooltips);
  g_object_set_data (G_OBJECT (check_tooltips), "tooltips", tooltips);
  gtk_box_pack_start (GTK_BOX (box_tooltips), check_tooltips, TRUE, TRUE, 0);

  /* 	GConf settings
   */
  rubrica_preferences_configure_check(client, check_tooltips, RUBRICA_KEY_TOOLTIPS);
  gconf_client_notify_add(client, RUBRICA_KEY_TOOLTIPS, 
			  rubrica_preferences_notify_tooltips_changes, 
			  check_tooltips, NULL, NULL);  
  
  /*    TOOLBAR settings
	toolbar style -- default: show both text and icons
  */
  toolbar_frame = rubrica_ui_frame_new(_("Toolbar"));
  g_object_set_data (G_OBJECT (preferences_dialog), "toolbar_frame", toolbar_frame);
  gtk_box_pack_start (GTK_BOX (box_general), toolbar_frame, FALSE, FALSE, 2);  

  box_toolbar = rubrica_ui_box_new(HBOX, FALSE, 0, 2);
  gtk_container_add (GTK_CONTAINER (toolbar_frame), box_toolbar);

  option_label = rubrica_ui_label_new(_("Toolbar show:"));
  gtk_box_pack_start(GTK_BOX(box_toolbar), option_label, FALSE, FALSE, 2);
  
  option_menu = rubrica_ui_option_menu_new(toolbar_option);
  gtk_box_pack_start(GTK_BOX(box_toolbar), option_menu, FALSE, FALSE, 5);


 /* 	GConf settings
  */ 
  rubrica_preferences_configure_option_menu(client, option_menu, RUBRICA_KEY_TOOLBAR_STYLE);
  gconf_client_notify_add(client, RUBRICA_KEY_TOOLBAR_STYLE, 
			  rubrica_preferences_notify_toolbar_style_changes,
			  option_menu, NULL, NULL); 

  /*    CALLBACKS
  */
  g_signal_connect (G_OBJECT (spin_width), "activate",
		    G_CALLBACK (on_spin_activate), RUBRICA_KEY_WIDTH);
  g_signal_connect (G_OBJECT (spin_width), "changed",
		    G_CALLBACK (on_spin_activate), RUBRICA_KEY_WIDTH);

  g_signal_connect (G_OBJECT (spin_length), "activate",
		    G_CALLBACK (on_spin_activate), RUBRICA_KEY_LENGTH);  
  g_signal_connect (G_OBJECT (spin_length), "changed",
		    G_CALLBACK (on_spin_activate), RUBRICA_KEY_LENGTH);  

  g_signal_connect (G_OBJECT (check_exit), "toggled",
		    G_CALLBACK (on_check_button_toggled), RUBRICA_KEY_EXIT);

  g_signal_connect (G_OBJECT (check_tooltips), "toggled", 
		    G_CALLBACK (on_check_button_toggled), RUBRICA_KEY_TOOLTIPS);

  g_signal_connect (G_OBJECT (option_menu), "changed", 
		    G_CALLBACK (on_option_menu_changed), RUBRICA_KEY_TOOLBAR_STYLE);  

  /*    
  g_signal_connect (G_OBJECT (check_tips), "toggled", 
                    G_CALLBACK (on_check_button_toggled), RUBRICA_KEY_TIPS);
  */
  
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), general_frame, NULL); 
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), general_frame);

  return page;
}



int 
rubrica_preferences_view_cards_columns(GConfClient *client, gchar *frame_label) 
{
  GtkWidget *frame;
  gint page;
  gchar *str;

  str = N_("Check the columns that you want to see in card's view");
  frame = rubrica_preferences_build_notebook_list_page(client, frame_label, 
						       str, PREF_CARD_LIST);

  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, NULL); 
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), frame);

  return page;
}


int 
rubrica_preferences_view_account_columns(GConfClient *client, gchar *frame_label)
{
  GtkWidget *frame;
  gint page;
  gchar *str;

  str = N_("Check the columns that you want to see in account's view");
  frame = rubrica_preferences_build_notebook_list_page(client, frame_label, 
						       str, PREF_ACCOUNT_LIST);
  
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, NULL); 
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), frame);

  return page;  
}


int
rubrica_preferences_view_personal_data(GConfClient *client, gchar *frame_label) 
{
  GtkWidget *frame;
  gint page;
  gchar *str;

  str = N_("Check the items that you want to see in Data window");
  frame = rubrica_preferences_build_notebook_list_page(client, frame_label, 
						       str, PREF_PERSONAL_DATA_LIST);
  
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, NULL); 
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), frame);

  return page;    
}


int 
rubrica_preferences_view_company_data(GConfClient *client, gchar *frame_label)
{
  GtkWidget *frame;
  gint page;
  gchar *str;

  str = N_("Check the items that you want to see in Data window");
  frame = rubrica_preferences_build_notebook_list_page(client, frame_label, 
						       str, PREF_COMPANY_DATA_LIST);
  
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, NULL); 
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), frame);

  return page;   
}


int 
rubrica_preferences_view_note_data(GConfClient *client, gchar *frame_label)
{
  GtkWidget *frame;
  gint page;
  gchar *str;

  str = N_("Check the items that you want to see in Data window");
  frame = rubrica_preferences_build_notebook_list_page(client, frame_label, 
						       str, PREF_NOTE_DATA_LIST);
  
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, NULL); 
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), frame);

  return page;   
}


int 
rubrica_preferences_dictionary(GConfClient *client, gchar *frame_label)
{
  gint page;
  GtkWidget *frame;
  GtkWidget *box_frame;

  GtkWidget *box_rules;
  GtkWidget *box_dict;
  GtkWidget *box_default_dict;
  GtkWidget *box_user_language;
  GtkWidget *box_io;
  GtkWidget *buttonbox_io;

  GtkWidget *load;
  GtkWidget *save;
  GtkWidget *show_rules;

  GSList *opt_other_lang_group = NULL;
  GSList *opt_def_lang_group = NULL;

  GtkWidget *radio_external_dict;
  GtkWidget *radio_default_dict;
  GtkWidget *radio_italian;
  GtkWidget *radio_english;  

  GtkWidget *notebook_dict;

  /*    entry
  */
  GtkWidget *entry_user_language;

  GtkWidget *entry_first_name;
  GtkWidget *entry_middle_name;
  GtkWidget *entry_last_name;
  GtkWidget *entry_profession;
  GtkWidget *entry_name_prefix;
  GtkWidget *entry_title;
  GtkWidget *entry_card;
  GtkWidget *entry_data;

  GtkWidget *entry_address;
  GtkWidget *entry_street;
  GtkWidget *entry_street_number;
  GtkWidget *entry_zip_code;
  GtkWidget *entry_city;
  GtkWidget *entry_province;
  GtkWidget *entry_country;
  GtkWidget *entry_state;

  GtkWidget *entry_web_address;
  GtkWidget *entry_web;
  GtkWidget *entry_email_address;
  GtkWidget *entry_email;

  GtkWidget *entry_tel_list;
  GtkWidget *entry_telephone;
  GtkWidget *entry_type;

  GtkWidget *entry_company_name;
  GtkWidget *entry_operator;
  GtkWidget *entry_green;
  GtkWidget *entry_company;
  GtkWidget *entry_customer_care;
  GtkWidget *entry_fax;

  GtkWidget *entry_assigment;
  GtkWidget *entry_organization;
  GtkWidget *entry_sub_dep;
  GtkWidget *entry_secretary_phone;
  GtkWidget *entry_department;
  GtkWidget *entry_secretary;
  GtkWidget *entry_work;

  GtkWidget *entry_anniversary;
  GtkWidget *entry_spouse_name;
  GtkWidget *entry_married;
  GtkWidget *entry_children;
  GtkWidget *entry_hobby;
  GtkWidget *entry_public_key;
  GtkWidget *entry_notes;
  GtkWidget *entry_child_notes;

  GtkWidget *entry_modify;
  GtkWidget *entry_delete;
  GtkWidget *entry_created;
  GtkWidget *entry_last_change;
  GtkWidget *entry_name;
  GtkWidget *entry_birthday;
  GtkWidget *entry_other_notes;

  /* ------------------------
   */
  GtkWidget *rules_frame;
  GtkWidget *io_frame;
  GtkWidget *dictionary_frame;
  GtkWidget *frame_personal_data;
  GtkWidget *frame_address;
  GtkWidget *frame_net;
  GtkWidget *frame_telephone;
  GtkWidget *frame_company;
  GtkWidget *frame_work;
  GtkWidget *frame_notes;
  GtkWidget *frame_misc;

  GtkWidget *table_personal_data;
  GtkWidget *table_address;
  GtkWidget *table_net;
  GtkWidget *table_telephone;
  GtkWidget *table_company;
  GtkWidget *table_work;
  GtkWidget *table_notes;
  GtkWidget *table_misc;

  GtkWidget *personal_tab;
  GtkWidget *address_tab;
  GtkWidget *net_tab;
  GtkWidget *telephone_tab;
  GtkWidget *company_tab;
  GtkWidget *work_tab;
  GtkWidget *notes_tab;
  GtkWidget *misc_tab;

  GtkWidget *lbl_io, *lbl_dict_name;
  GtkWidget *lbl_dictionary, *lbl_default_dict, *lbl_user_language;


  GtkWidget *vseparator2;


  frame     = rubrica_ui_frame_new(frame_label);
  box_frame = rubrica_ui_box_new(VBOX, FALSE, 0, 2);
  gtk_container_add(GTK_CONTAINER(frame), box_frame);

  rules_frame = rubrica_ui_frame_new(_("Rubrica's Dictionary"));
  gtk_box_pack_start (GTK_BOX (box_frame), rules_frame, FALSE, FALSE, 2);

  box_rules = rubrica_ui_box_new(VBOX, FALSE, 0, 2);
  gtk_container_add (GTK_CONTAINER (rules_frame), box_rules);
  
  box_dict = rubrica_ui_box_new(HBOX, FALSE, 0, 2);
  gtk_box_pack_start (GTK_BOX (box_rules), box_dict, TRUE, TRUE, 0);

  lbl_dictionary = rubrica_ui_label_new(_("Rubrica will use:  "));
  gtk_box_pack_start (GTK_BOX (box_dict), lbl_dictionary, FALSE, TRUE, 0);

  /*     RADIO BUTTONS
	 
         - DEFAULT DICTIONARY
	 - EXTERNAL DICTIONARY
	 
	 default: use one of the default dictionary
  */

  radio_external_dict = gtk_radio_button_new_with_mnemonic(opt_other_lang_group,  
							_("an exter_nal dictionary"));
  opt_other_lang_group = gtk_radio_button_group(GTK_RADIO_BUTTON(radio_external_dict));
  g_object_set_data(G_OBJECT(preferences_dialog), 
		      RUBRICA_KEY_EXTERNAL, radio_external_dict);
  gtk_box_pack_start (GTK_BOX (box_dict), radio_external_dict, FALSE, TRUE, 0);
  gtk_widget_show (radio_external_dict);
  gtk_tooltips_set_tip (tooltips, radio_external_dict, _("uses an external dictionary "
							 "when show preview"), NULL);

  radio_default_dict = gtk_radio_button_new_with_mnemonic(opt_other_lang_group, 
						       _("a de_fault dictionary"));
  opt_other_lang_group = gtk_radio_button_group(GTK_RADIO_BUTTON (radio_default_dict));
  g_object_set_data(G_OBJECT (preferences_dialog), 
		      RUBRICA_KEY_DEFAULT, radio_default_dict);
  gtk_box_pack_start (GTK_BOX (box_dict), radio_default_dict, FALSE, TRUE, 0);
  gtk_widget_show (radio_default_dict);
  gtk_tooltips_set_tip (tooltips, radio_default_dict, _("uses one of the following "
							"default dictionary"), NULL);

  box_default_dict = rubrica_ui_box_new(HBOX, FALSE, 0, 2);
  gtk_box_pack_start (GTK_BOX (box_rules), box_default_dict, TRUE, TRUE, 0);

  lbl_default_dict = rubrica_ui_label_new(_("Use as my default dictionary: "));
  g_object_set_data (G_OBJECT (preferences_dialog), "lbl_default_dict", lbl_default_dict);
  gtk_box_pack_start (GTK_BOX (box_default_dict), lbl_default_dict, FALSE, TRUE, 0);
  
  /*    RADIO BUTTONS
    
        - ITALIAN DICTIONARY
	- ENGLISH DICTIONARY

	default: use italian dictionary
  */
  radio_italian = gtk_radio_button_new_with_mnemonic(opt_def_lang_group, _("_Italian"));
  opt_def_lang_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_italian));
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_ITALIAN, radio_italian);
  gtk_box_pack_start (GTK_BOX (box_default_dict), radio_italian, FALSE, TRUE, 0);
  gtk_widget_show (radio_italian);

  radio_english = gtk_radio_button_new_with_mnemonic(opt_def_lang_group, _("_English"));
  opt_def_lang_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_english));
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_ENGLISH, radio_english);
  gtk_box_pack_start (GTK_BOX (box_default_dict), radio_english, FALSE, TRUE, 0);
  gtk_widget_show (radio_english);

  box_user_language = rubrica_ui_box_new(HBOX, FALSE, 0, 2);
  gtk_box_pack_start (GTK_BOX (box_rules), box_user_language, TRUE, TRUE, 0);

  lbl_user_language = rubrica_ui_label_new(_("Rubrica will use this language:"));
  g_object_set_data (G_OBJECT (preferences_dialog), "lbl_language", lbl_user_language); 
  gtk_box_pack_start(GTK_BOX (box_user_language), lbl_user_language, FALSE, TRUE, 0);
  
  /*    ENTRY TEXT
        USER LANGUAGES
   */
  entry_user_language = gtk_entry_new ();
  g_object_set_data (G_OBJECT (preferences_dialog), RUBRICA_KEY_USER_DICTIONARY, 
		       entry_user_language);
  gtk_box_pack_start(GTK_BOX (box_user_language), entry_user_language, TRUE, TRUE, 0);
  gtk_widget_show (entry_user_language);
  gtk_tooltips_set_tip (tooltips, entry_user_language,_("the language's name will be "
							"used as dictionary file name"), NULL);

  dictionary_frame = rubrica_ui_frame_new(_("Dictionary"));
  gtk_box_pack_start (GTK_BOX (box_frame), dictionary_frame, FALSE, FALSE, 0);

  /*      dictionary notebook 
  */
  notebook_dict = gtk_notebook_new ();
  g_object_set_data(G_OBJECT (preferences_dialog), "notebook_dict", notebook_dict);
  gtk_container_add (GTK_CONTAINER (dictionary_frame), notebook_dict);
  gtk_container_set_border_width (GTK_CONTAINER (notebook_dict), 2);
  gtk_widget_show (notebook_dict);

  frame_personal_data = rubrica_ui_frame_new(_("Personal dictionary"));
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_personal_data);

  table_personal_data = gtk_table_new (5, 4, FALSE);
  gtk_widget_show (table_personal_data);
  gtk_container_add (GTK_CONTAINER (frame_personal_data), table_personal_data);
  gtk_container_set_border_width (GTK_CONTAINER (table_personal_data), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_personal_data), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_personal_data), 10);

  /*    dictionary --  personal data
   */
  rubrica_ui_tabled_label_new(table_personal_data, _("First name"),  0, 1, 0, 1);
  rubrica_ui_tabled_label_new(table_personal_data, _("Last name"),   0, 1, 1, 2);
  rubrica_ui_tabled_label_new(table_personal_data, _("Name Prefix"), 0, 1, 2, 3);
  rubrica_ui_tabled_label_new(table_personal_data, _("Data"),        0, 1, 3, 4); 
  rubrica_ui_tabled_label_new(table_personal_data, _("Middle name"), 2, 3, 0, 1);
  rubrica_ui_tabled_label_new(table_personal_data, _("Profession"),  2, 3, 1, 2);
  rubrica_ui_tabled_label_new(table_personal_data, _("Title"),       2, 3, 2, 3);
  rubrica_ui_tabled_label_new(table_personal_data, _("Card"),        2, 3, 3, 4);

  /*    personal dictionary entry
  */
  entry_first_name  = rubrica_ui_tabled_entry_new(table_personal_data, 1, 2, 0, 1);
  entry_middle_name = rubrica_ui_tabled_entry_new(table_personal_data, 3, 4, 0, 1);
  entry_last_name   = rubrica_ui_tabled_entry_new(table_personal_data, 1, 2, 1, 2);
  entry_profession  = rubrica_ui_tabled_entry_new(table_personal_data, 3, 4, 1, 2);
  entry_name_prefix = rubrica_ui_tabled_entry_new(table_personal_data, 1, 2, 2, 3);
  entry_title       = rubrica_ui_tabled_entry_new(table_personal_data, 3, 4, 2, 3);
  entry_card        = rubrica_ui_tabled_entry_new(table_personal_data, 3, 4, 3, 4);
  entry_data        = rubrica_ui_tabled_entry_new(table_personal_data, 1, 2, 3, 4);

  g_object_set_data (G_OBJECT (preferences_dialog), "entry_first_name", entry_first_name);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_middle_name",entry_middle_name);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_last_name", entry_last_name);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_profession", entry_profession);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_name_prefix",entry_name_prefix);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_title", entry_title);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_card", entry_card);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_data", entry_data);

  personal_tab = gtk_label_new (_("Personal"));
  gtk_widget_show (personal_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict),
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_dict), 0), 
			      personal_tab);
  /*    frame address
  */
  frame_address = rubrica_ui_frame_new(_("Address  dictionary"));
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_address);

  table_address = gtk_table_new (5, 4, FALSE);
  gtk_container_add (GTK_CONTAINER (frame_address), table_address);
  gtk_container_set_border_width (GTK_CONTAINER (table_address), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_address), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_address), 3);
  gtk_widget_show (table_address);

  rubrica_ui_tabled_label_new(table_address, _("Street"),        0, 1, 0, 1);
  rubrica_ui_tabled_label_new(table_address, _("Street number"), 2, 3, 0, 1);
  rubrica_ui_tabled_label_new(table_address, _("Zip code"),      0, 1, 1, 2);
  rubrica_ui_tabled_label_new(table_address, _("City"),          2, 3, 1, 2);
  rubrica_ui_tabled_label_new(table_address, _("Province"),      0, 1, 2, 3);
  rubrica_ui_tabled_label_new(table_address, _("Country"),       0, 1, 3, 4);
  rubrica_ui_tabled_label_new(table_address, _("State"),         2, 3, 2, 3);
  rubrica_ui_tabled_label_new(table_address, _("Address"),       2, 3, 3, 4);

  /*    address dictionary entry
  */
  entry_street        = rubrica_ui_tabled_entry_new(table_address, 1, 2, 0, 1);
  entry_street_number = rubrica_ui_tabled_entry_new(table_address, 3, 4, 0, 1);
  entry_city          = rubrica_ui_tabled_entry_new(table_address, 3, 4, 1, 2);
  entry_state         = rubrica_ui_tabled_entry_new(table_address, 3, 4, 2, 3);
  entry_address       = rubrica_ui_tabled_entry_new(table_address, 3, 4, 3, 4);
  entry_zip_code      = rubrica_ui_tabled_entry_new(table_address, 1, 2, 1, 2);
  entry_province      = rubrica_ui_tabled_entry_new(table_address, 1, 2, 2, 3);
  entry_country       = rubrica_ui_tabled_entry_new(table_address, 1, 2, 3, 4);

  g_object_set_data (G_OBJECT (preferences_dialog), "entry_street", entry_street);
  g_object_set_data (G_OBJECT(preferences_dialog),  "entry_street_number",
		       entry_street_number);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_city", entry_city);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_state", entry_state);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_address", entry_address);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_zip_code", entry_zip_code);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_province", entry_province);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_country", entry_country);

  address_tab = gtk_label_new (_("Address"));
  gtk_widget_show (address_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict), 
			      gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook_dict), 1), 
			      address_tab);

  /*  frame net
   */
  frame_net = rubrica_ui_frame_new(_("Net dictionary"));
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_net);

  table_net = gtk_table_new (3, 4, FALSE);
  gtk_container_add (GTK_CONTAINER (frame_net), table_net);
  gtk_container_set_border_width (GTK_CONTAINER (table_net), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_net), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_net), 3);
  gtk_widget_show (table_net);

  rubrica_ui_tabled_label_new(table_net, _("Web"),           2, 3, 0, 1);
  rubrica_ui_tabled_label_new(table_net, _("Email address"), 0, 1, 1, 2);
  rubrica_ui_tabled_label_new(table_net, _("Email"),         2, 3, 1, 2);
  rubrica_ui_tabled_label_new(table_net, _("Web address"),   0, 1, 0, 1);

  /*    net dictionary entry
  */
  entry_web_address   = rubrica_ui_tabled_entry_new(table_net, 1, 2, 0, 1);
  entry_web           = rubrica_ui_tabled_entry_new(table_net, 3, 4, 0, 1);
  entry_email         = rubrica_ui_tabled_entry_new(table_net, 3, 4, 1, 2);
  entry_email_address = rubrica_ui_tabled_entry_new(table_net, 1, 2, 1, 2);

  g_object_set_data(G_OBJECT (preferences_dialog), "entry_web_address", entry_web_address);
  g_object_set_data(G_OBJECT (preferences_dialog), "entry_web", entry_web);
  g_object_set_data(G_OBJECT (preferences_dialog), "entry_email", entry_email);
  g_object_set_data(G_OBJECT (preferences_dialog), "entry_email_address",
		      entry_email_address);

  net_tab = gtk_label_new (_("Net"));
  gtk_widget_show (net_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict), 
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK(notebook_dict), 2), 
			      net_tab);

  /*    frame telephone
  */
  frame_telephone = rubrica_ui_frame_new(_(" Telephone dictionary "));
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_telephone);
  gtk_widget_show (frame_telephone);

  table_telephone = gtk_table_new (3, 4, FALSE);
  gtk_container_add (GTK_CONTAINER (frame_telephone), table_telephone);
  gtk_container_set_border_width (GTK_CONTAINER (table_telephone), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_telephone), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_telephone), 3);
  gtk_widget_show (table_telephone);

  rubrica_ui_tabled_label_new(table_telephone, _("Telephone List"), 0, 1, 0, 1);
  rubrica_ui_tabled_label_new(table_telephone, _("Telephone "),     2, 3, 0, 1);
  rubrica_ui_tabled_label_new(table_telephone, _("Type"),           0, 1, 1, 2);

  /*    telephone dictionary entry
  */
  entry_tel_list  = rubrica_ui_tabled_entry_new(table_telephone, 1, 2, 0, 1);
  entry_telephone = rubrica_ui_tabled_entry_new(table_telephone, 3, 4, 0, 1);
  entry_type      = rubrica_ui_tabled_entry_new(table_telephone, 1, 2, 1, 2);

  g_object_set_data (G_OBJECT (preferences_dialog), "entry_tel_list", entry_tel_list);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_telephone", entry_telephone);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_type", entry_type);

  telephone_tab = gtk_label_new (_("Telephone"));
  gtk_widget_show (telephone_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict), 
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_dict), 3),
			      telephone_tab);

  /*    company frame
  */
  frame_company = rubrica_ui_frame_new(_(" Company dictionary "));
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_company);
  gtk_widget_show (frame_company);

  table_company = gtk_table_new (5, 4, FALSE);
  gtk_container_add (GTK_CONTAINER (frame_company), table_company);
  gtk_container_set_border_width (GTK_CONTAINER (table_company), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_company), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_company), 3);
  gtk_widget_show (table_company);


  rubrica_ui_tabled_label_new(table_company, _("Company Name"),  0, 1, 0, 1);
  rubrica_ui_tabled_label_new(table_company, _("Operator"),      2, 3, 0, 1);
  rubrica_ui_tabled_label_new(table_company, _("Fax"),           0, 1, 1, 2);
  rubrica_ui_tabled_label_new(table_company, _("Green"),         2, 3, 1, 2);
  rubrica_ui_tabled_label_new(table_company, _("Customer care"), 0, 1, 2, 3);
  rubrica_ui_tabled_label_new(table_company, _("Company"),       2, 3, 2, 3);


  /*    company dictionary entry
  */
  entry_company_name  = rubrica_ui_tabled_entry_new(table_company, 1, 2, 0, 1);
  entry_operator      = rubrica_ui_tabled_entry_new(table_company, 3, 4, 0, 1);
  entry_fax           = rubrica_ui_tabled_entry_new(table_company, 1, 2, 1, 2);
  entry_green         = rubrica_ui_tabled_entry_new(table_company, 3, 4, 1, 2);
  entry_customer_care = rubrica_ui_tabled_entry_new(table_company, 1, 2, 2, 3);
  entry_company       = rubrica_ui_tabled_entry_new(table_company, 3, 4, 2, 3);

  g_object_set_data (G_OBJECT (preferences_dialog), "entry_company_name", 
		       entry_company_name);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_operator", entry_operator);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_green", entry_green);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_company", entry_company);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_customer_care",
		       entry_customer_care);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_fax", entry_fax);

  company_tab = gtk_label_new (_("Company"));
  gtk_widget_show (company_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict), 
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_dict), 4), 
			      company_tab);

  /*    work frame
   */
  frame_work = rubrica_ui_frame_new(_("Work dictionary"));
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_work);
  gtk_widget_show (frame_work);

  table_work = gtk_table_new (5, 4, FALSE);
  gtk_container_add (GTK_CONTAINER (frame_work), table_work);
  gtk_container_set_border_width (GTK_CONTAINER (table_work), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_work), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_work), 3);
  gtk_widget_show (table_work);

  rubrica_ui_tabled_label_new(table_work, _("Department"),      0, 1, 1, 2);
  rubrica_ui_tabled_label_new(table_work, _("Secretary"),       0, 1, 2, 3);
  rubrica_ui_tabled_label_new(table_work, _("Work"),            0, 1, 3, 4);
  rubrica_ui_tabled_label_new(table_work, _("Secretary Phone"), 2, 3, 2, 3);
  rubrica_ui_tabled_label_new(table_work, _("Sub department"),  2, 3, 1, 2);
  rubrica_ui_tabled_label_new(table_work, _("Organization"),    2, 3, 0, 1);
  rubrica_ui_tabled_label_new(table_work, _("Assigment"),       0, 1, 0, 1);

  /*    work dictionary entry
  */
  entry_assigment       = rubrica_ui_tabled_entry_new(table_work, 1, 2, 0, 1);
  entry_organization    = rubrica_ui_tabled_entry_new(table_work, 3, 4, 0, 1);
  entry_sub_dep         = rubrica_ui_tabled_entry_new(table_work, 3, 4, 1, 2);
  entry_secretary_phone = rubrica_ui_tabled_entry_new(table_work, 3, 4, 2, 3);
  entry_department      = rubrica_ui_tabled_entry_new(table_work, 1, 2, 1, 2);
  entry_secretary       = rubrica_ui_tabled_entry_new(table_work, 1, 2, 2, 3);
  entry_work            = rubrica_ui_tabled_entry_new(table_work, 1, 2, 3, 4);

  g_object_set_data (G_OBJECT (preferences_dialog), "entry_assigment",  entry_assigment);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_organization",
		       entry_organization);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_sub_dep", entry_sub_dep);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_secretary_phone",
		       entry_secretary_phone);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_department", entry_department);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_secretary", entry_secretary);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_work", entry_work);

  work_tab = gtk_label_new (_("Work"));
  gtk_widget_show (work_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict), 
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_dict), 5),
			      work_tab);

  /*    frame notes
  */
  frame_notes = rubrica_ui_frame_new(_("Notes dictionary"));
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_notes);
  gtk_widget_show (frame_notes);

  table_notes = gtk_table_new (5, 4, FALSE);
  gtk_container_add (GTK_CONTAINER (frame_notes), table_notes);
  gtk_container_set_border_width (GTK_CONTAINER (table_notes), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_notes), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_notes), 3);
  gtk_widget_show (table_notes);

  rubrica_ui_tabled_label_new(table_notes, _("Spouse Name"),    0, 1, 0, 1);
  rubrica_ui_tabled_label_new(table_notes, _("Married"),        0, 1, 1, 2);
  rubrica_ui_tabled_label_new(table_notes, _("Children notes"), 0, 1, 2, 3);
  rubrica_ui_tabled_label_new(table_notes, _("Note"),           0, 1, 3, 4);
  rubrica_ui_tabled_label_new(table_notes, _("Anniversary"),    2, 3, 0, 1);
  rubrica_ui_tabled_label_new(table_notes, _("Children"),       2, 3, 1, 2);
  rubrica_ui_tabled_label_new(table_notes, _("Hobby"),          2, 3, 2, 3);
  rubrica_ui_tabled_label_new(table_notes, _("Public Key"),     2, 3, 3, 4);

  entry_spouse_name = rubrica_ui_tabled_entry_new(table_notes, 1, 2, 0, 1);
  entry_married     = rubrica_ui_tabled_entry_new(table_notes, 1, 2, 1, 2);
  entry_child_notes = rubrica_ui_tabled_entry_new(table_notes, 1, 2, 2, 3);
  entry_notes       = rubrica_ui_tabled_entry_new(table_notes, 1, 2, 3, 4);
  entry_anniversary = rubrica_ui_tabled_entry_new(table_notes, 3, 4, 0, 1);
  entry_children    = rubrica_ui_tabled_entry_new(table_notes, 3, 4, 1, 2);
  entry_hobby       = rubrica_ui_tabled_entry_new(table_notes, 3, 4, 2, 3);
  entry_public_key  = rubrica_ui_tabled_entry_new(table_notes, 3, 4, 3, 4);

  g_object_set_data (G_OBJECT (preferences_dialog), "entry_anniversary",entry_anniversary);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_spouse_name",entry_spouse_name);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_married", entry_married);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_children", entry_children);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_hobby", entry_hobby);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_public_key", entry_public_key);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_notes", entry_notes);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_child_notes",entry_child_notes);

  notes_tab = gtk_label_new (_("Notes"));
  gtk_widget_show (notes_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict),  
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_dict), 6), 
			      notes_tab);
  /*    frame misc
  */
  frame_misc = rubrica_ui_frame_new(_("Misc dictionary"));
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_misc);

  table_misc = gtk_table_new (5, 4, FALSE);
  gtk_container_add (GTK_CONTAINER (frame_misc), table_misc);
  gtk_container_set_border_width (GTK_CONTAINER (table_misc), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_misc), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_misc), 3);
  gtk_widget_show (table_misc);

  rubrica_ui_tabled_label_new(table_misc, _("Deleting"),    0, 1, 0, 1);
  rubrica_ui_tabled_label_new(table_misc, _("Modifying"),   2, 3, 0, 1);
  rubrica_ui_tabled_label_new(table_misc, _("Created"),     0, 1, 1, 2);
  rubrica_ui_tabled_label_new(table_misc, _("Last Change"), 2, 3, 1, 2);
  rubrica_ui_tabled_label_new(table_misc, _("Birthday"),    0, 1, 2, 3);
  rubrica_ui_tabled_label_new(table_misc, _("Name"),        2, 3, 2, 3);
  rubrica_ui_tabled_label_new(table_misc, _("Other Notes"), 0, 1, 3, 4);

  entry_delete = rubrica_ui_tabled_entry_new(table_misc, 1, 2, 0, 1);
  entry_modify = rubrica_ui_tabled_entry_new(table_misc, 3, 4, 0, 1);
  entry_last_change = rubrica_ui_tabled_entry_new(table_misc, 3, 4, 1, 2);
  entry_name        = rubrica_ui_tabled_entry_new(table_misc, 3, 4, 2, 3);
  entry_created     = rubrica_ui_tabled_entry_new(table_misc, 1, 2, 1, 2);
  entry_birthday    = rubrica_ui_tabled_entry_new(table_misc, 1, 2, 2, 3);
  entry_other_notes = rubrica_ui_tabled_entry_new(table_misc, 1, 2, 3, 4);

  g_object_set_data (G_OBJECT (preferences_dialog), "entry_delete",entry_delete);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_modify",entry_modify);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_last_change",entry_last_change);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_name", entry_name);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_created",entry_created);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_birthday",entry_birthday);
  g_object_set_data (G_OBJECT (preferences_dialog), "entry_other_notes",entry_other_notes);

  misc_tab = gtk_label_new (_("Misc"));
  gtk_widget_show (misc_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict),  
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_dict), 7), 
			      misc_tab);

  /*    IO frame
  */
  io_frame = rubrica_ui_frame_new(_("Save and Load Dictionary"));
  gtk_box_pack_start (GTK_BOX (box_frame), io_frame, FALSE, FALSE, 2);
  gtk_widget_show (io_frame);

  box_io = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (box_io);
  gtk_container_add (GTK_CONTAINER (io_frame), box_io);
  gtk_container_set_border_width (GTK_CONTAINER (box_io), 2);

  /*      input/output labels 
   */
  lbl_io = gtk_label_new (_("Dictionary name:"));
  g_object_set_data (G_OBJECT (preferences_dialog), "lbl_io", lbl_io);
  gtk_widget_show (lbl_io);
  gtk_box_pack_start (GTK_BOX (box_io), lbl_io, FALSE, FALSE, 0);
 
  lbl_dict_name = gtk_label_new ("");
  g_object_set_data (G_OBJECT (preferences_dialog), "lbl_dict_name", lbl_dict_name);
  gtk_widget_show (lbl_dict_name);
  gtk_box_pack_start (GTK_BOX (box_io), lbl_dict_name, TRUE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (lbl_dict_name), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (lbl_dict_name), 0, 0.5);
  
  vseparator2 = gtk_vseparator_new ();
  gtk_widget_show (vseparator2);
  gtk_box_pack_start (GTK_BOX (box_io), vseparator2, FALSE, TRUE, 0);

  buttonbox_io = gtk_hbutton_box_new ();
  gtk_widget_show (buttonbox_io);
  gtk_box_pack_start (GTK_BOX (box_io), buttonbox_io, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (buttonbox_io), 2);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (buttonbox_io), GTK_BUTTONBOX_SPREAD);
  gtk_button_box_set_spacing (GTK_BUTTON_BOX (buttonbox_io), 5);
  gtk_button_box_set_child_size (GTK_BUTTON_BOX (buttonbox_io), 80, 27);
  gtk_button_box_set_child_ipadding (GTK_BUTTON_BOX (buttonbox_io), 4, 0);

  /*    load and save dictionary buttons
  */
  load = gtk_button_new_with_label (_("_Load"));
  g_object_set_data (G_OBJECT (preferences_dialog), "load", load);
  gtk_widget_show (load);
  gtk_container_add (GTK_CONTAINER (buttonbox_io), load);
  GTK_WIDGET_SET_FLAGS (load, GTK_CAN_DEFAULT);
  gtk_tooltips_set_tip (tooltips, load, _("Load dictionary and show it"), NULL);

  save = gtk_button_new_with_label (_("_Save"));
  g_object_set_data (G_OBJECT (preferences_dialog), "save", save);
  gtk_widget_show (save);
  gtk_container_add (GTK_CONTAINER (buttonbox_io), save);
  GTK_WIDGET_SET_FLAGS (save, GTK_CAN_DEFAULT);
  gtk_tooltips_set_tip (tooltips, save, _("Save dictionary"), NULL);

  show_rules = gtk_button_new_with_label (_("Show _Rules"));
  gtk_widget_show (show_rules);
  gtk_container_add (GTK_CONTAINER (buttonbox_io), show_rules);
  GTK_WIDGET_SET_FLAGS (show_rules, GTK_CAN_DEFAULT);
  gtk_tooltips_set_tip (tooltips, show_rules, _("Show translation rules"), NULL);


  /* ---------------------------------------------------------------------
     GConf settings
     ---------------------------------------------------------------------  */
  rubrica_preferences_configure_radio_dictionary(client, 
						 radio_external_dict, 
						 radio_default_dict,  
						 RUBRICA_KEY_EXTERNAL,
						 RUBRICA_KEY_DEFAULT);  
/*
  rubrica_preferences_configure_radio(radio_italian, radio_english, client, 
				      RUBRICA_KEY_ITALIAN, RUBRICA_KEY_ENGLISH);  
*/
  rubrica_preferences_configure_radio(client, 2, 
				      radio_italian, RUBRICA_KEY_ITALIAN,  
				      radio_english, RUBRICA_KEY_ENGLISH); 

  rubrica_preferences_configure_label(client, lbl_dict_name, RUBRICA_KEY_USER_DICTIONARY);

  rubrica_preferences_configure_entry(client, entry_user_language, 
				      RUBRICA_KEY_USER_DICTIONARY);

  /* ---------------------------------------------------------------------  */

  g_signal_connect (G_OBJECT (radio_external_dict), "toggled",
                      G_CALLBACK (on_radio_button_toggled),
                      RUBRICA_KEY_EXTERNAL);
  g_signal_connect (G_OBJECT (radio_default_dict), "toggled",
                      G_CALLBACK (on_radio_button_toggled),
                      RUBRICA_KEY_DEFAULT);

  g_signal_connect (G_OBJECT (radio_italian), "toggled",
                      G_CALLBACK (on_radio_button_toggled),
                      RUBRICA_KEY_ITALIAN);
  g_signal_connect (G_OBJECT (radio_english), "toggled",
                      G_CALLBACK (on_radio_button_toggled),
                      RUBRICA_KEY_ENGLISH);

  g_signal_connect (G_OBJECT (entry_user_language), "changed",
		      G_CALLBACK (on_entry_changed),
                      RUBRICA_KEY_USER_DICTIONARY);

  /*    dictionary entry callbacks
  */
  
  /*    personal
  */
  g_signal_connect (G_OBJECT (entry_first_name), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_FIRST_NAME);
  g_signal_connect (G_OBJECT (entry_middle_name), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_MIDDLE_NAME);
  g_signal_connect (G_OBJECT (entry_last_name), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_LAST_NAME);
  g_signal_connect (G_OBJECT (entry_profession), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_PROFESSION);
  g_signal_connect (G_OBJECT (entry_name_prefix), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_NAME_PREFIX);
  g_signal_connect (G_OBJECT (entry_title), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_TITLE);
  g_signal_connect (G_OBJECT (entry_card), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_CARD);
  g_signal_connect (G_OBJECT (entry_data), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_DATA);

  /*    address
  */
  g_signal_connect (G_OBJECT (entry_address), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_ADDRESS);
  g_signal_connect (G_OBJECT (entry_street), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_STREET);
  g_signal_connect (G_OBJECT (entry_street_number), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
		      RUBRICA_KEY_DICT_STREET_NUMBER);
  g_signal_connect (G_OBJECT (entry_zip_code), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_ZIP_CODE);
  g_signal_connect (G_OBJECT (entry_city), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_CITY);
  g_signal_connect (G_OBJECT (entry_province), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_PROVINCE);
  g_signal_connect (G_OBJECT (entry_country), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
		      RUBRICA_KEY_DICT_COUNTRY);
  g_signal_connect (G_OBJECT (entry_state), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_STATE);

  /*    net
  */
  g_signal_connect (G_OBJECT (entry_web_address), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_WEB_ADDRESS);
  g_signal_connect (G_OBJECT (entry_web), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_WEB);
  g_signal_connect (G_OBJECT (entry_email_address), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_EMAIL_ADDRESS);
  g_signal_connect (G_OBJECT (entry_email), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_EMAIL);

  /*    telephone
  */
  g_signal_connect (G_OBJECT (entry_tel_list), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_TELEPHONE_LIST);
  g_signal_connect (G_OBJECT (entry_telephone), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_TELEPHONE_NUMBER);
  g_signal_connect (G_OBJECT (entry_type), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_TELEPHONE_TYPE);

  /*    company
  */
  g_signal_connect (G_OBJECT (entry_company_name), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_COMPANY_NAME);
  g_signal_connect (G_OBJECT (entry_operator), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_OPERATOR);
  g_signal_connect (G_OBJECT (entry_green), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_GREEN);
  g_signal_connect (G_OBJECT (entry_company), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_COMPANY);
  g_signal_connect (G_OBJECT (entry_customer_care), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_CUSTOMER_CARE);
   g_signal_connect (G_OBJECT (entry_fax), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_FAX);
 
  /*    work
   */
  g_signal_connect (G_OBJECT (entry_work), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_WORK);
  g_signal_connect (G_OBJECT (entry_assigment), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_ASSIGMENT);
  g_signal_connect (G_OBJECT (entry_organization), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_ORGANIZATION);
  g_signal_connect (G_OBJECT (entry_department), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_DEPARTMENT);
  g_signal_connect (G_OBJECT (entry_sub_dep), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_SUB_DEPARTMENT);
  g_signal_connect (G_OBJECT (entry_secretary), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_SECRETARY);
  g_signal_connect (G_OBJECT (entry_secretary_phone), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_SECRETARY_PHONE);

  /*    notes
   */
  g_signal_connect (G_OBJECT (entry_spouse_name), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_SPOUSE_NAME);
  g_signal_connect (G_OBJECT (entry_married), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_MARRIED);
  g_signal_connect (G_OBJECT (entry_anniversary), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_ANNIVERSARY);
  g_signal_connect (G_OBJECT (entry_children), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_CHILDREN);
  g_signal_connect (G_OBJECT (entry_child_notes), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_CHILDREN_NOTES);
  g_signal_connect (G_OBJECT (entry_hobby), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_HOBBY);
  g_signal_connect (G_OBJECT (entry_notes), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_NOTES);
  g_signal_connect (G_OBJECT (entry_public_key), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_PUBLIC_KEY);

  /*    misc
  */
  g_signal_connect (G_OBJECT (entry_modify), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_MODIFY);
  g_signal_connect (G_OBJECT (entry_delete), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_DELETE);
  g_signal_connect (G_OBJECT (entry_created), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_CREATED);
  g_signal_connect (G_OBJECT (entry_last_change), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_LAST_CHANGE);
  g_signal_connect (G_OBJECT (entry_name), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_CARD_NAME);
  g_signal_connect (G_OBJECT (entry_birthday), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_BIRTHDAY);
  g_signal_connect (G_OBJECT (entry_other_notes), "changed",
                      G_CALLBACK (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_OTHER_NOTES);

  /*      notebook dictionary buttons callbacks 
  */
  g_signal_connect (G_OBJECT (load), "clicked",
                      G_CALLBACK (on_load_dictionary_clicked),
                      entry_user_language);
  g_signal_connect (G_OBJECT (save), "clicked",
                      G_CALLBACK (on_save_dictionary_clicked),
		      entry_user_language);
  g_signal_connect (G_OBJECT (show_rules), "clicked",
                      G_CALLBACK (on_show_rules_clicked),
                      NULL);

  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, NULL); 
  page = gtk_notebook_page_num(GTK_NOTEBOOK(notebook), frame); 

  return page;
}


