/*
*  Rubrica
*  file: utils.c
*
*  
*  Copyright (C) 2000-2002 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <gnome.h>
#include <string.h>
#include <time.h>

#include "utils.h"
#include "rubrica_type.h"

static GList *pixmaps_directories = NULL;
static GList *tooltip_list = NULL;
GList *netlist = NULL, *tellist = NULL;



void 
rubrica_utils_add_tooltip(GtkTooltips *tooltip)
{
  tooltip_list = g_list_prepend(tooltip_list, tooltip);
}

void 
rubrica_utils_enable_tooltips(void)
{
  GList *alias = tooltip_list;

  while (alias)
    {
      gtk_tooltips_enable(GTK_TOOLTIPS(alias->data));

      alias = g_list_next(alias);
    }
}


void 
rubrica_utils_disable_tooltips(void)
{
  GList *alias = tooltip_list;

  while (alias)
    {
      gtk_tooltips_disable(GTK_TOOLTIPS(alias->data));

      alias = g_list_next(alias);
    }  
}


/* derived from code build by glade 
*/
void 
rubrica_utils_add_pixmap_directory(const gchar *directory)
{
  pixmaps_directories = g_list_prepend (pixmaps_directories, g_strdup (directory));
}

/* derived from code build by glade 
*/
gchar*
rubrica_utils_find_pixmap_file (const gchar *filename)
{
  GList *elem;

  /* We step through each of the pixmaps directory to find it. */
  elem = pixmaps_directories;
  while (elem)
    {
      gchar *pathname = g_strdup_printf ("%s%s%s", (gchar*)elem->data, 
					 G_DIR_SEPARATOR_S, filename);
      
      if (g_file_test (pathname, G_FILE_TEST_EXISTS))
        return pathname;
      g_free (pathname);
      elem = elem->next;
    }
  return NULL;
}

/* This is used to set ATK action descriptions. 
 */
void
rubrica_utils_set_atk_action_description (AtkAction *action, const gchar *action_name,
					  const gchar *description)
{
  gint n_actions, i;

  n_actions = atk_action_get_n_actions (action);
  for (i = 0; i < n_actions; i++)
    {
      if (!strcmp (atk_action_get_name (action, i), action_name))
        atk_action_set_description (action, i, description);
    }
}


/*
 */
GList*
rubrica_utils_get_all_data(GtkWidget *tree, RubricaTreeType type)
{
  GtkTreeModel *model;

  model = gtk_tree_view_get_model(GTK_TREE_VIEW(tree));
  netlist = tellist = NULL;  /* global variables */

  switch (type)
    {
    case CARD_TREE:
      break;

    case ACCOUNT_TREE:
      break;

    case NET_TREE:
      gtk_tree_model_foreach(GTK_TREE_MODEL(model), rubrica_utils_extract_net_data, NULL);  

      return netlist;
      break;

    case PHONE_TREE:
      gtk_tree_model_foreach(GTK_TREE_MODEL(model), rubrica_utils_extract_phone_data, NULL);

      return tellist;
      break;

    default:
      break;
    }
  
  return NULL;
}


gboolean 
rubrica_utils_extract_net_data(GtkTreeModel *model, GtkTreePath *path,
			       GtkTreeIter *iter, gpointer data)
{
  gchar *str;

  gtk_tree_model_get(model, iter, URI_COLUMN, &str, -1);
  netlist = g_list_append(netlist, str);
  
  return FALSE;
}


gboolean 
rubrica_utils_extract_phone_data(GtkTreeModel *model, GtkTreePath *path,
				 GtkTreeIter *iter, gpointer data)
{
  TelNum *tt;
  gchar *number;
  gchar *type;

  tt = (TelNum *) g_malloc(sizeof(TelNum));

  gtk_tree_model_get(model, iter, NUMBER_COLUMN, &number, TYPE_COLUMN, &type, -1);
  
  tt->number = g_strdup(number);
  tt->type = g_strdup(type);
  tellist = g_list_append(tellist, tt);

  return FALSE;
}


/* 
*/
RubricaTelephoneType rubrica_utils_telephone2int(gchar *tipo)
{
  g_return_val_if_fail(tipo != NULL, TELEPHONE_UNKNOWN);

  if ((strcasecmp(tipo, "home") == 0) ||      
      (strcasecmp(tipo, "Casa") == 0))
    return TELEPHONE_HOME;

  if ((strcasecmp(tipo, "work") == 0) ||
      (strcasecmp(tipo, "Ufficio") == 0))
    return TELEPHONE_WORK;

  if ((strcasecmp(tipo, "fax") == 0) ||
      (strcasecmp(tipo, "Fax") == 0))
    return TELEPHONE_FAX;
  
  if ((strcasecmp(tipo, "cellphone") == 0) ||
      (strcasecmp(tipo, "Cellulare") == 0))
    return TELEPHONE_CELLPHONE;

  if ((strcasecmp(tipo, "other") == 0) ||
      (strcasecmp(tipo, "Altro") == 0))
    return TELEPHONE_OTHER;

  return TELEPHONE_UNKNOWN;
}



gchar*
rubrica_utils_convert_time(time_t t,/*  RubricaTimeFormatType type,*/ gboolean has_hour)
{
  struct tm *loctime;
  gchar *buffer;
  
  buffer = g_malloc(sizeof(gchar)*256);
  
  if (t == 0)
    {
      buffer = "";
      return buffer;
    }

  loctime = localtime(&t);
  if (has_hour)
    strftime(buffer, 256, "%m/%d/%Y %H:%M:%S %Z", loctime);
  else
    strftime(buffer, 256, "%m/%d/%Y", loctime);

/*
  switch (type)
    {
    case RT_DMY:
      if (has_hour)
	strftime(buffer, 256, "%d/%m/%Y %H:%M:%S %Z", loctime);
      else
	strftime(buffer, 256, "%d/%m/%Y", loctime);
      break;

    case RT_MDY:
      if (has_hour)
	strftime(buffer, 256, "%m/%d/%Y %H:%M:%S %Z", loctime);
      else
	strftime(buffer, 256, "%m/%d/%Y", loctime);
      break;

    default:
      break;
    }
*/
  return buffer;     
}



gint rubrica_utils_option_len(RubricaOptionType *option)
{
  RubricaOptionType *opt = option;
  gint i = 0;

  while(opt->pixmap)
    {
      i++;
      opt++;
    }

  return i;
}



/*  Debug functions, ignore :)
*/
void 
rubrica_utils_debug_net_list(GList *lst)
{
  while (lst)
    {
      if (lst && lst->data)
	g_print("\n*** DEBUG NET LIST -- elemento: %s --  ***", (gchar *)lst->data);

      lst = lst->next;
    }
}


void 
rubrica_utils_debug_tel_list(GList *lst)
{
  while (lst)
    {
      TelNum *tn;

      if (lst && lst->data)
	{
	  tn = (TelNum *) lst->data;

	  g_print("\n*** DEBUG TEL LIST -- elemento: %s %s --  ***", 
		  (gchar *)tn->number, 
		  (gchar *)tn->type);
	}

      lst = lst->next;
    }
}
